@@ -1,92 +1,35 @@
 /*
- * $Header: /home/cvs/jakarta-tomcat-4.0/catalina/src/share/org/apache/catalina/core/ApplicationContext.java,v 1.41 2003/02/12 10:24:09 remm Exp $
- * $Revision: 1.41 $
- * $Date: 2003/02/12 10:24:09 $
- *
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Tomcat", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
- *
- * [Additional notices, if required by prior licensing conditions]
- *
+ * Copyright 1999,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 
 package org.apache.catalina.core;
 
 
-import java.io.BufferedReader;
 import java.io.InputStream;
-import java.io.IOException;
 import java.io.File;
-import java.io.UnsupportedEncodingException;
 import java.net.MalformedURLException;
-import java.net.Socket;
 import java.net.URL;
 import java.security.AccessController;
-import java.security.Principal;
 import java.security.PrivilegedAction;
 import java.security.PrivilegedExceptionAction;
 import java.security.PrivilegedActionException;
 import java.util.ArrayList;
-import java.util.Arrays;
-import java.util.Collections;
 import java.util.Enumeration;
 import java.util.HashMap;
-import java.util.HashSet;
 import java.util.Iterator;
-import java.util.Locale;
-import java.util.Map;
 import java.util.Set;
 import javax.naming.NamingException;
 import javax.naming.Binding;
@@ -96,24 +39,14 @@ import javax.servlet.Servlet;
 import javax.servlet.ServletContext;
 import javax.servlet.ServletContextAttributeEvent;
 import javax.servlet.ServletContextAttributeListener;
-import javax.servlet.ServletInputStream;
-import javax.servlet.ServletRequest;
-import javax.servlet.http.Cookie;
 import javax.servlet.http.HttpServletRequest;
-import javax.servlet.http.HttpSession;
 import org.apache.naming.resources.Resource;
 import org.apache.naming.resources.DirContextURLStreamHandler;
-import org.apache.naming.resources.DirContextURLConnection;
-import org.apache.catalina.Connector;
-import org.apache.catalina.Container;
 import org.apache.catalina.Context;
-import org.apache.catalina.Globals;
 import org.apache.catalina.Host;
 import org.apache.catalina.HttpRequest;
 import org.apache.catalina.Logger;
-import org.apache.catalina.Response;
 import org.apache.catalina.Wrapper;
-import org.apache.catalina.connector.HttpRequestBase;
 import org.apache.catalina.deploy.ApplicationParameter;
 import org.apache.catalina.util.Enumerator;
 import org.apache.catalina.util.ResourceSet;
@@ -128,11 +61,51 @@ import org.apache.catalina.util.StringManager;
  *
  * @author Craig R. McClanahan
  * @author Remy Maucherat
- * @version $Revision: 1.41 $ $Date: 2003/02/12 10:24:09 $
+ * @version $Revision: 1.45 $ $Date: 2004/08/26 21:31:21 $
  */
 
-public class ApplicationContext
-    implements ServletContext {
+public class ApplicationContext implements ServletContext {
+
+    protected class PrivilegedGetInitParameter implements PrivilegedAction {
+
+        private String name;
+        
+        PrivilegedGetInitParameter(String name){
+            this.name = name;
+        }
+                
+        public Object run(){
+            return ((String) parameters.get(name));
+        }
+    }
+
+
+    protected class PrivilegedGetInitParameterNames
+        implements PrivilegedAction {
+
+            PrivilegedGetInitParameterNames(){
+        }
+   
+        public Object run() {
+            return (new Enumerator(parameters.keySet()));
+        }
+    }        
+
+
+    protected class PrivilegedGetNamedDispatcher
+        implements PrivilegedAction {
+
+            private Wrapper wrapper;
+            private String name;
+
+            PrivilegedGetNamedDispatcher(Wrapper wrapper, String name) {
+            this.wrapper = wrapper;
+            this.name = name;
+        }
+        public Object run() {
+            return new ApplicationDispatcher(wrapper, null, null, null, name);
+        }
+    }
 
 
     protected class PrivilegedGetRequestDispatcher
@@ -177,6 +150,7 @@ public class ApplicationContext
     }
 
 
+
     protected class PrivilegedGetResource
         implements PrivilegedExceptionAction {
 
@@ -252,6 +226,7 @@ public class ApplicationContext
     protected class PrivilegedLogThrowable
         implements PrivilegedAction {
 
+
         private String message;
         private Throwable throwable;
 
@@ -442,7 +417,9 @@ public class ApplicationContext
         String contextPath = context.getPath();
         if (!contextPath.endsWith("/"))
             contextPath = contextPath + "/";
-        if ((contextPath.length() > 1) && (uri.startsWith(contextPath))) {
+
+        if (((contextPath.length() > 1) && (uri.startsWith(contextPath))) ||
+            ((contextPath.equals("/")) && (uri.equals("/")))) {
             return (this);
         }
 
@@ -469,13 +446,17 @@ public class ApplicationContext
      *
      * @param name Name of the initialization parameter to retrieve
      */
-    public String getInitParameter(String name) {
-
+    public String getInitParameter(final String name) {
         mergeParameters();
         synchronized (parameters) {
-            return ((String) parameters.get(name));
+            if (System.getSecurityManager() != null){
+                PrivilegedGetInitParameter ip =
+                    new PrivilegedGetInitParameter(name);
+                return (String)AccessController.doPrivileged(ip);
+            } else {
+                return ((String) parameters.get(name));
+            }                   
         }
-
     }
 
 
@@ -484,12 +465,16 @@ public class ApplicationContext
      * empty enumeration if the context has no initialization parameters.
      */
     public Enumeration getInitParameterNames() {
-
         mergeParameters();
         synchronized (parameters) {
-            return (new Enumerator(parameters.keySet()));
+            if (System.getSecurityManager() != null){
+                PrivilegedGetInitParameterNames pn =
+                    new PrivilegedGetInitParameterNames();
+                return (Enumeration)AccessController.doPrivileged(pn);
+            } else {
+                return (new Enumerator(parameters.keySet()));
+            }
         }
-
     }
 
 
@@ -550,10 +535,18 @@ public class ApplicationContext
         Wrapper wrapper = (Wrapper) context.findChild(name);
         if (wrapper == null)
             return (null);
-        ApplicationDispatcher dispatcher =
-          new ApplicationDispatcher(wrapper, null, null, null, name);
-        return ((RequestDispatcher) dispatcher);
 
+        ApplicationDispatcher dispatcher;
+        if (System.getSecurityManager() != null){
+            PrivilegedGetNamedDispatcher nd = 
+                new PrivilegedGetNamedDispatcher(wrapper, name);
+            dispatcher = (ApplicationDispatcher)AccessController.doPrivileged(nd);
+        } else {
+            dispatcher =
+                new ApplicationDispatcher(wrapper, null, null, null, name);
+        }
+
+        return ((RequestDispatcher) dispatcher);
     }
 
 
@@ -691,6 +684,7 @@ public class ApplicationContext
      * return <code>null</code>.
      *
      * @param path The path to the desired resource.
+
      */
     public InputStream getResourceAsStream(String path) {
 
@@ -790,9 +784,18 @@ public class ApplicationContext
      * @deprecated As of Java Servlet API 2.1, with no direct replacement.
      */
     public Enumeration getServletNames() {
+        if (System.getSecurityManager() != null){
+            return (Enumeration)AccessController.doPrivileged(
+                new PrivilegedAction(){
 
-        return (new Enumerator(empty));
-
+                    public Object run(){
+                        return (new Enumerator(empty)); 
+                    }
+                }
+            );
+        } else {
+            return (new Enumerator(empty));
+        }
     }
 
 
@@ -800,9 +803,18 @@ public class ApplicationContext
      * @deprecated As of Java Servlet API 2.1, with no direct replacement.
      */
     public Enumeration getServlets() {
+        if (System.getSecurityManager() != null){
+            return (Enumeration)AccessController.doPrivileged(
+                new PrivilegedAction(){
 
-        return (new Enumerator(empty));
-
+                    public Object run(){
+                        return (new Enumerator(empty)); 
+                    }
+                }
+            );
+        } else {
+            return (new Enumerator(empty));
+        }        
     }
 
 
@@ -1157,3 +1169,4 @@ public class ApplicationContext
 
 
 }
+
