@@ -1,64 +1,17 @@
 /*
- * $Header: /home/cvs/jakarta-tomcat-4.0/catalina/src/share/org/apache/catalina/loader/WebappClassLoader.java,v 1.48 2003/03/08 14:20:45 glenn Exp $
- * $Revision: 1.48 $
- * $Date: 2003/03/08 14:20:45 $
- *
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Tomcat", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
- *
- * [Additional notices, if required by prior licensing conditions]
- *
+ * Copyright 1999,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 
@@ -69,13 +22,9 @@ import java.io.FilePermission;
 import java.io.InputStream;
 import java.io.ByteArrayInputStream;
 import java.io.IOException;
-import java.net.JarURLConnection;
 import java.net.MalformedURLException;
 import java.net.URL;
 import java.net.URLClassLoader;
-import java.net.URLConnection;
-import java.net.URLStreamHandlerFactory;
-import java.net.URLStreamHandler;
 import java.security.AccessControlException;
 import java.security.AccessController;
 import java.security.CodeSource;
@@ -83,7 +32,6 @@ import java.security.Permission;
 import java.security.PermissionCollection;
 import java.security.Policy;
 import java.security.PrivilegedAction;
-import java.security.cert.Certificate;
 import java.util.ArrayList;
 import java.util.Enumeration;
 import java.util.HashMap;
@@ -91,7 +39,6 @@ import java.util.Iterator;
 import java.util.Vector;
 import java.util.jar.JarFile;
 import java.util.jar.JarEntry;
-import java.util.jar.JarInputStream;
 import java.util.jar.Manifest;
 import java.util.jar.Attributes;
 import java.util.jar.Attributes.Name;
@@ -102,9 +49,9 @@ import javax.naming.NamingEnumeration;
 import javax.naming.NameClassPair;
 
 import org.apache.catalina.Lifecycle;
-import org.apache.catalina.LifecycleEvent;
 import org.apache.catalina.LifecycleException;
 import org.apache.catalina.LifecycleListener;
+import org.apache.catalina.util.URLEncoder;
 
 import org.apache.naming.JndiPermission;
 import org.apache.naming.resources.ResourceAttributes;
@@ -145,7 +92,7 @@ import org.apache.naming.resources.Resource;
  *
  * @author Remy Maucherat
  * @author Craig R. McClanahan
- * @version $Revision: 1.48 $ $Date: 2003/03/08 14:20:45 $
+ * @version $Revision: 1.54 $ $Date: 2004/08/26 21:34:02 $
  */
 public class WebappClassLoader
     extends URLClassLoader
@@ -294,6 +241,12 @@ public class WebappClassLoader
 
 
     /**
+     * Repositories URLs, used to cache the result of getURLs. 
+     */ 
+    protected URL[] repositoryURLs = null; 
+
+
+    /** 
      * Repositories translated as path in the work directory (for Jasper
      * originally), but which is used to generate fake URLs should getURLs be
      * called.
@@ -571,6 +524,7 @@ public class WebappClassLoader
             URL url = new URL(repository);
             super.addURL(url);
             hasExternalRepositories = true;
+            repositoryURLs = null;
         } catch (MalformedURLException e) {
             throw new IllegalArgumentException(e.toString());
         }
@@ -929,6 +883,15 @@ public class WebappClassLoader
     // ---------------------------------------------------- ClassLoader Methods
 
 
+    /**
+     * Add the specified URL to the classloader.
+     */
+    protected void addURL(URL url) { 
+        super.addURL(url); 
+        hasExternalRepositories = true; 
+        repositoryURLs = null; 
+    } 
+
     /**
      * Find the specified class in our local repositories, if possible.  If
      * not found, throw <code>ClassNotFoundException</code>.
@@ -1326,6 +1289,7 @@ public class WebappClassLoader
         // Don't load classes if class loader is stopped
         if (!started) {
             log("Lifecycle error : CL stopped");
+            Thread.dumpStack();
             throw new ClassNotFoundException(name);
         }
 
@@ -1483,6 +1447,10 @@ public class WebappClassLoader
      */
     public URL[] getURLs() {
 
+        if (repositoryURLs != null) {
+            return repositoryURLs;
+        }
+
         URL[] external = super.getURLs();
 
         int filesLength = files.length;
@@ -1503,12 +1471,13 @@ public class WebappClassLoader
                 }
             }
 
-            return urls;
-
+            repositoryURLs = urls; 
+    
         } catch (MalformedURLException e) {
-            return (new URL[0]);
+            repositoryURLs = new URL[0];
         }
 
+        return repositoryURLs; 
     }
 
 
@@ -1576,6 +1545,7 @@ public class WebappClassLoader
         notFoundResources.clear();
         resourceEntries.clear();
         repositories = new String[0];
+        repositoryURLs = null;
         files = new File[0];
         jarFiles = new JarFile[0];
         jarRealFiles = new File[0];
@@ -1878,8 +1848,8 @@ public class WebappClassLoader
      */
     protected boolean isPackageSealed(String name, Manifest man) {
 
-        String path = name + "/";
-        Attributes attr = man.getAttributes(path);
+        String path = name.replace('.', '/') + '/';
+        Attributes attr = man.getAttributes(path); 
         String sealed = null;
         if (attr != null) {
             sealed = attr.getValue(Name.SEALED);
@@ -2061,8 +2031,21 @@ public class WebappClassLoader
         }
 
         //return new URL("file:" + realFile.getPath());
-        return realFile.toURL();
+        URLEncoder urlEncoder = new URLEncoder();
+        urlEncoder.addSafeCharacter(',');
+        urlEncoder.addSafeCharacter(':');
+        urlEncoder.addSafeCharacter('-');
+        urlEncoder.addSafeCharacter('_');
+        urlEncoder.addSafeCharacter('.');
+        urlEncoder.addSafeCharacter('*');
+        urlEncoder.addSafeCharacter('/');
+        urlEncoder.addSafeCharacter('!');
+        urlEncoder.addSafeCharacter('~');
+        urlEncoder.addSafeCharacter('\'');
+        urlEncoder.addSafeCharacter('(');
+        urlEncoder.addSafeCharacter(')');
 
+        return new URL(urlEncoder.encode(realFile.toURL().toString()));
     }
 
 
