@@ -1,77 +1,35 @@
 /*
- * CGIServlet.java $Header: /home/cvs/jakarta-tomcat-4.0/catalina/src/share/org/apache/catalina/servlets/CGIServlet.java,v 1.17 2004/01/18 17:48:11 markt Exp $
- * $Revision: 1.17 $, $Date: 2004/01/18 17:48:11 $
- *
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Tomcat", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
- *
- *
+ * Copyright 1999,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 
 package org.apache.catalina.servlets;
 
+import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.FileOutputStream;
 import java.io.BufferedWriter;
 import java.io.BufferedReader;
 import java.io.InputStream;
 import java.io.InputStreamReader;
+import java.io.OutputStream;
 import java.io.OutputStreamWriter;
 import java.io.BufferedOutputStream;
 import java.io.IOException;
 import java.net.URLEncoder;
+import java.util.ArrayList;
 import java.util.Hashtable;
 import java.util.Vector;
 import java.util.Enumeration;
@@ -277,7 +235,7 @@ import org.apache.catalina.util.IOTools;
  *
  * @author Martin T Dengler [root@martindengler.com]
  * @author Amy Roh
- * @version $Revision: 1.17 $, $Date: 2004/01/18 17:48:11 $
+ * @version $Revision: 1.27 $, $Date: 2004/08/26 21:38:13 $
  * @since Tomcat 4.0
  *
  */
@@ -288,21 +246,12 @@ public class CGIServlet extends HttpServlet {
 
     /* some vars below copied from Craig R. McClanahan's InvokerServlet */
 
-    /** the string manager for this package. */
-    /* YAGNI
-    private static StringManager sm =
-        StringManager.getManager(Constants.Package);
-    */
-
     /** the Context container associated with our web application. */
     private ServletContext context = null;
 
     /** the debugging detail level for this servlet. */
     private int debug = 0;
 
-    /** the time in ms to wait for the client to send us CGI input data */
-    private int iClientInputTimeout = 100;
-
     /**
      *  The CGI search path will start at
      *    webAppRootDir + File.separator + cgiPathPrefix
@@ -314,9 +263,15 @@ public class CGIServlet extends HttpServlet {
     /** the executable to use with the script */
     private String cgiExecutable = "perl";
     
+    /** the encoding to use for parameters */
+    private String parameterEncoding = System.getProperty("file.encoding",
+                                                          "UTF-8");
+
     /** object used to ensure multiple threads don't try to expand same file */
     static Object expandFileLock = new Object();
 
+    /** the shell environment variables to be passed to the CGI script */
+    static Hashtable shellEnv = new Hashtable();
 
     /**
      * Sets instance variables.
@@ -345,6 +300,8 @@ public class CGIServlet extends HttpServlet {
             throw new UnavailableException
                 ("Cannot invoke CGIServlet through the invoker");
 
+        boolean passShellEnvironment = false;
+        
         // Set our properties from the initialization parameters
         String value = null;
         try {
@@ -352,27 +309,29 @@ public class CGIServlet extends HttpServlet {
             debug = Integer.parseInt(value);
             cgiPathPrefix =
                 getServletConfig().getInitParameter("cgiPathPrefix");
-            value =
-                getServletConfig().getInitParameter("iClientInputTimeout");
-            iClientInputTimeout = Integer.parseInt(value);
+            value = getServletConfig().getInitParameter("passShellEnvironment");
+            passShellEnvironment = Boolean.valueOf(value).booleanValue();
         } catch (Throwable t) {
             //NOOP
         }
         log("init: loglevel set to " + debug);
 
+        if (passShellEnvironment) {
+            try {
+                shellEnv.putAll(getShellEnvironment());
+            } catch (IOException ioe) {
+                ServletException e = new ServletException(
+                        "Unable to read shell environment variables", ioe);
+            }
+        }
+
         value = getServletConfig().getInitParameter("executable");
         if (value != null) {
             cgiExecutable = value;
         }
 
         // Identify the internal container resources we need
-        //Wrapper wrapper = (Wrapper) getServletConfig();
-        //context = (Context) wrapper.getParent();
-
         context = config.getServletContext();
-        if (debug >= 1) {
-            //log("init: Associated with Context '" + context.getPath() + "'");
-        }
 
     }
 
@@ -648,7 +607,7 @@ public class CGIServlet extends HttpServlet {
             try {
                 ServletOutputStream out = res.getOutputStream();
                 out.println("<HTML><HEAD><TITLE>$Name:  $</TITLE></HEAD>");
-                out.println("<BODY>$Header: /home/cvs/jakarta-tomcat-4.0/catalina/src/share/org/apache/catalina/servlets/CGIServlet.java,v 1.17 2004/01/18 17:48:11 markt Exp $<p>");
+                out.println("<BODY>$Header: /home/cvs/jakarta-tomcat-4.0/catalina/src/share/org/apache/catalina/servlets/CGIServlet.java,v 1.27 2004/08/26 21:38:13 markt Exp $<p>");
 
                 if (cgiEnv.isValid()) {
                     out.println(cgiEnv.toString());
@@ -690,11 +649,52 @@ public class CGIServlet extends HttpServlet {
 
     /** For future testing use only; does nothing right now */
     public static void main(String[] args) {
-        System.out.println("$Header: /home/cvs/jakarta-tomcat-4.0/catalina/src/share/org/apache/catalina/servlets/CGIServlet.java,v 1.17 2004/01/18 17:48:11 markt Exp $");
+        System.out.println("$Header: /home/cvs/jakarta-tomcat-4.0/catalina/src/share/org/apache/catalina/servlets/CGIServlet.java,v 1.27 2004/08/26 21:38:13 markt Exp $");
     }
 
+    /**
+     * Get all shell environment variables. Have to do it this rather ugly way
+     * as the API to obtain is not available in 1.4 and earlier APIs.
+     *
+     * See <a href="http://www.rgagnon.com/javadetails/java-0150.html">Read environment
+     * variables from an application</a> for original source and article.
+     */
+    private Hashtable getShellEnvironment() throws IOException {
+        Hashtable envVars = new Hashtable();
+        Process p = null;
+        Runtime r = Runtime.getRuntime();
+        String OS = System.getProperty("os.name").toLowerCase();
+        boolean ignoreCase;
 
+        if (OS.indexOf("windows 9") > -1) {
+            p = r.exec( "command.com /c set" );
+            ignoreCase = true;
+        } else if ( (OS.indexOf("nt") > -1)
+                || (OS.indexOf("windows 2000") > -1)
+                || (OS.indexOf("windows xp") > -1) ) {
+            // thanks to JuanFran for the xp fix!
+            p = r.exec( "cmd.exe /c set" );
+            ignoreCase = true;
+        } else {
+            // our last hope, we assume Unix (thanks to H. Ware for the fix)
+            p = r.exec( "env" );
+            ignoreCase = false;
+        }
 
+        BufferedReader br = new BufferedReader
+            ( new InputStreamReader( p.getInputStream() ) );
+        String line;
+        while( (line = br.readLine()) != null ) {
+            int idx = line.indexOf( '=' );
+            String key = line.substring( 0, idx );
+            String value = line.substring( idx+1 );
+            if (ignoreCase) {
+                key = key.toUpperCase();
+            }
+            envVars.put(key, value);
+        }
+        return envVars;
+    }
 
 
 
@@ -706,7 +706,7 @@ public class CGIServlet extends HttpServlet {
      * </p>
      *
      * @author   Martin Dengler [root@martindengler.com]
-     * @version  $Revision: 1.17 $, $Date: 2004/01/18 17:48:11 $
+     * @version  $Revision: 1.27 $, $Date: 2004/08/26 21:38:13 $
      * @since    Tomcat 4.0
      *
      */
@@ -741,7 +741,7 @@ public class CGIServlet extends HttpServlet {
         private File workingDirectory = null;
 
         /** cgi command's query parameters */
-        private Hashtable queryParameters = null;
+        private ArrayList queryParameters = new ArrayList();
 
         /** whether or not this object is valid or not */
         private boolean valid = false;
@@ -762,13 +762,17 @@ public class CGIServlet extends HttpServlet {
             setupFromContext(context);
             setupFromRequest(req);
 
-            queryParameters = new Hashtable();
             Enumeration paramNames = req.getParameterNames();
             while (paramNames != null && paramNames.hasMoreElements()) {
                 String param = paramNames.nextElement().toString();
                 if (param != null) {
-                    queryParameters.put(
-                        param, URLEncoder.encode(req.getParameter(param)));
+                    String values[] = req.getParameterValues(param);
+                    for (int i=0; i < values.length; i++) {
+                        String value = URLEncoder.encode(values[i],
+                                                         parameterEncoding);
+                        NameValuePair nvp = new NameValuePair(param, value);
+                        queryParameters.add(nvp);
+                    }
                 }
             }
 
@@ -967,6 +971,10 @@ public class CGIServlet extends HttpServlet {
 
             Hashtable envp = new Hashtable();
 
+            // Add the shell environment variables (if any)
+            envp.putAll(shellEnv);
+
+            // Add the CGI environment variables
             String sPathInfoOrig = null;
             String sPathTranslatedOrig = null;
             String sPathInfoCGI = null;
@@ -1266,13 +1274,12 @@ public class CGIServlet extends HttpServlet {
             sb.append("</td></tr>");
 
             sb.append("<tr><td colspan=2>Query Params</td></tr>");
-            Enumeration paramk = queryParameters.keys();
-            while (paramk.hasMoreElements()) {
-                String s = paramk.nextElement().toString();
+            for (int i=0; i < queryParameters.size(); i++) {
+                NameValuePair nvp = (NameValuePair) queryParameters.get(i);
                 sb.append("<tr><td>");
-                sb.append(s);
+                sb.append(nvp.getName());
                 sb.append("</td><td>");
-                sb.append(queryParameters.get(s).toString());
+                sb.append(nvp.getValue());
                 sb.append("</td></tr>");
             }
 
@@ -1325,7 +1332,7 @@ public class CGIServlet extends HttpServlet {
          * @return   CGI query parameters
          *
          */
-        protected Hashtable getParameters() {
+        protected ArrayList getParameters() {
             return queryParameters;
         }
 
@@ -1419,7 +1426,7 @@ public class CGIServlet extends HttpServlet {
      * </p>
      *
      * @author    Martin Dengler [root@martindengler.com]
-     * @version   $Revision: 1.17 $, $Date: 2004/01/18 17:48:11 $
+     * @version   $Revision: 1.27 $, $Date: 2004/08/26 21:38:13 $
      */
 
     protected class CGIRunner {
@@ -1434,7 +1441,7 @@ public class CGIServlet extends HttpServlet {
         private File wd = null;
 
         /** query parameters to be passed to the invoked script */
-        private Hashtable params = null;
+        private ArrayList params = null;
 
         /** stdin to be passed to cgi script */
         private InputStream stdin = null;
@@ -1459,14 +1466,11 @@ public class CGIServlet extends HttpServlet {
          * @param  command  string full path to command to be executed
          * @param  env      Hashtable with the desired script environment
          * @param  wd       File with the script's desired working directory
-         * @param  params   Hashtable with the script's query parameters
-         *
-         * @param  res       HttpServletResponse object for setting headers
-         *                   based on CGI script output
-         *
+         * @param  params   ArrayList with the script's query parameters as
+         *                  NameValuePairs
          */
         protected CGIRunner(String command, Hashtable env, File wd,
-                            Hashtable params) {
+                            ArrayList params) {
             this.command = command;
             this.env = env;
             this.wd = wd;
@@ -1639,13 +1643,13 @@ public class CGIServlet extends HttpServlet {
              */
             Runtime rt = null;
             BufferedReader commandsStdOut = null;
+            InputStream cgiOutput = null;
             BufferedReader commandsStdErr = null;
             BufferedOutputStream commandsStdIn = null;
             Process proc = null;
             int bufRead = -1;
 
             //create query arguments
-            Enumeration paramNames = params.keys();
             StringBuffer cmdAndArgs = new StringBuffer();
             if (command.indexOf(" ") < 0) {
                 cmdAndArgs.append(command);
@@ -1655,143 +1659,70 @@ public class CGIServlet extends HttpServlet {
                 cmdAndArgs.append(command);
                 cmdAndArgs.append("\"");
             }
-            
-            if (paramNames != null && paramNames.hasMoreElements()) {
+
+            for (int i=0; i < params.size(); i++) {
                 cmdAndArgs.append(" ");
-                while (paramNames.hasMoreElements()) {
-                    String k = (String) paramNames.nextElement();
-                    String v = params.get(k).toString();
-                    if ((k.indexOf("=") < 0) && (v.indexOf("=") < 0)) {
-                        StringBuffer arg = new StringBuffer(k);
-                        arg.append("=");
-                        v = java.net.URLEncoder.encode(v);
-                        arg.append(v);
-                        if (arg.toString().indexOf(" ") < 0) {
-                            cmdAndArgs.append(arg);
-                        } else {
-                            // Spaces used as delimiter, so need to use quotes
-                            cmdAndArgs.append("\"");
-                            cmdAndArgs.append(arg);
-                            cmdAndArgs.append("\"");
-                        }
-                        cmdAndArgs.append(" ");
+                NameValuePair nvp = (NameValuePair) params.get(i); 
+                String k = nvp.getName();
+                String v = nvp.getValue();
+                if ((k.indexOf("=") < 0) && (v.indexOf("=") < 0)) {
+                    StringBuffer arg = new StringBuffer(k);
+                    arg.append("=");
+                    arg.append(v);
+                    if (arg.toString().indexOf(" ") < 0) {
+                        cmdAndArgs.append(arg);
+                    } else {
+                        // Spaces used as delimiter, so need to use quotes
+                        cmdAndArgs.append("\"");
+                        cmdAndArgs.append(arg);
+                        cmdAndArgs.append("\"");
                     }
                 }
             }
 
-            /*String postIn = getPostInput(params);
-            int contentLength = (postIn.length()
-                    + System.getProperty("line.separator").length());
-            if ("POST".equals(env.get("REQUEST_METHOD"))) {
-                env.put("CONTENT_LENGTH", new Integer(contentLength));
-            }*/
-
-        //if (command.endsWith(".pl") || command.endsWith(".cgi")) {
             StringBuffer command = new StringBuffer(cgiExecutable);
             command.append(" ");
             command.append(cmdAndArgs.toString());
             cmdAndArgs = command;
-        //}
+
+            String sContentLength = (String) env.get("CONTENT_LENGTH");
+            ByteArrayOutputStream contentStream = null;
+            if(!"".equals(sContentLength)) {
+                byte[] content = new byte[Integer.parseInt(sContentLength)];
+                int lenRead = stdin.read(content);
+                contentStream = new ByteArrayOutputStream(
+                        Integer.parseInt(sContentLength));
+                if ("POST".equals(env.get("REQUEST_METHOD"))) {
+                    String paramStr = getPostInput(params);
+                    if (paramStr != null) {
+                        byte[] paramBytes = paramStr.getBytes();
+                        contentStream.write(paramBytes);
+
+                        int contentLength = paramBytes.length;
+                        if (lenRead > 0) {
+                            String lineSep = System.getProperty("line.separator");
+                            contentStream.write(lineSep.getBytes());
+                            contentLength = lineSep.length() + lenRead;
+                        }
+                        env.put("CONTENT_LENGTH", new Integer(contentLength));
+                    }
+                }
+
+                if (lenRead > 0) {
+                    contentStream.write(content, 0, lenRead);
+                }
+                contentStream.close();
+            }
 
             rt = Runtime.getRuntime();
             proc = rt.exec(cmdAndArgs.toString(), hashToStringArray(env), wd);
 
-            /*
-             * provide input to cgi
-             * First  -- parameters
-             * Second -- any remaining input
-             */
-            /*commandsStdIn = new BufferedOutputStream(proc.getOutputStream());
-            if (debug >= 2 ) {
-                log("runCGI stdin=[" + stdin + "], qs="
-                    + env.get("QUERY_STRING"));
+            if(contentStream != null) {
+                commandsStdIn = new BufferedOutputStream(proc.getOutputStream());
+                proc.getOutputStream().write(contentStream.toByteArray());
+                commandsStdIn.flush();
+                commandsStdIn.close();
             }
-            if ("POST".equals(env.get("REQUEST_METHOD"))) {
-                if (debug >= 2) {
-                    log("runCGI: writing ---------------\n");
-                    log(postIn);
-                    log("runCGI: new content_length=" + contentLength
-                        + "---------------\n");
-                }
-                commandsStdIn.write(postIn.getBytes());
-            }
-            if (stdin != null) {
-                //REMIND: document this
-                /* assume if nothing is available after a time, that nothing is
-                 * coming...
-                 */
-                /*if (stdin.available() <= 0) {
-                    if (debug >= 2 ) {
-                        log("runCGI stdin is NOT available ["
-                            + stdin.available() + "]");
-                    }
-                    try {
-                        Thread.currentThread().sleep(iClientInputTimeout);
-                    } catch (InterruptedException ignored) {
-                    }
-                }
-                if (stdin.available() > 0) {
-                    if (debug >= 2 ) {
-                        log("runCGI stdin IS available ["
-                            + stdin.available() + "]");
-                    }
-                    byte[] bBuf = new byte[1024];
-                    bufRead = -1;
-                    try {
-                        while ((bufRead = stdin.read(bBuf)) != -1) {
-                            if (debug >= 2 ) {
-                                log("runCGI: read [" + bufRead
-                                    + "] bytes from stdin");
-                            }
-                            commandsStdIn.write(bBuf, 0, bufRead);
-                        }
-                        if (debug >= 2 ) {
-                            log("runCGI: DONE READING from stdin");
-                        }
-                    } catch (IOException ioe) {
-                        //REMIND: replace with logging
-                        //REMIND: should I throw this exception?
-                        log("runCGI: couldn't write all bytes.");
-                        ioe.printStackTrace();
-                    }
-                }
-            }
-            commandsStdIn.flush();
-            commandsStdIn.close();*/
-      String sContentLength = (String) env.get("CONTENT_LENGTH");
-      if(!"".equals(sContentLength)) {
-          commandsStdIn = new BufferedOutputStream(proc.getOutputStream());
-          byte[] content = new byte[Integer.parseInt(sContentLength)];
-
-          int lenRead = stdin.read(content);
-
-          if ("POST".equals(env.get("REQUEST_METHOD"))) {
-              String paramStr = getPostInput(params);
-              if (paramStr != null) {
-                  byte[] paramBytes = paramStr.getBytes();
-                  commandsStdIn.write(paramBytes);
-
-                  int contentLength = paramBytes.length;
-                  if (lenRead > 0) {
-                      String lineSep = System.getProperty("line.separator");
-
-                      commandsStdIn.write(lineSep.getBytes());
-
-                      contentLength = lineSep.length() + lenRead;
-                  }
-
-                  env.put("CONTENT_LENGTH", new Integer(contentLength));
-              }
-          }
-
-          if (lenRead > 0) {
-              commandsStdIn.write(content, 0, lenRead);
-          }
-
-
-          commandsStdIn.flush();
-          commandsStdIn.close();
-      }
 
             /* we want to wait for the process to exit,  Process.waitFor()
              * is useless in our situation; see
@@ -1800,8 +1731,6 @@ public class CGIServlet extends HttpServlet {
              */
 
             boolean isRunning = true;
-            commandsStdOut = new BufferedReader
-                (new InputStreamReader(proc.getInputStream()));
             commandsStdErr = new BufferedReader
                 (new InputStreamReader(proc.getErrorStream()));
             BufferedWriter servletContainerStdout = null;
@@ -1823,14 +1752,17 @@ public class CGIServlet extends HttpServlet {
                 } ;
             }.start() ;
 
-
+            InputStream cgiHeaderStream =
+                new HTTPHeaderInputStream(proc.getInputStream());
+            BufferedReader cgiHeaderReader =
+                new BufferedReader(new InputStreamReader(cgiHeaderStream));
+            boolean isBinaryContent = false;
+            
             while (isRunning) {
-
                 try {
-
                     //set headers
                     String line = null;
-                    while (((line = commandsStdOut.readLine()) != null)
+                    while (((line = cgiHeaderReader.readLine()) != null)
                            && !("".equals(line))) {
                         if (debug >= 2) {
                             log("runCGI: addHeader(\"" + line + "\")");
@@ -1841,27 +1773,50 @@ public class CGIServlet extends HttpServlet {
                              * response.setStatus(getStatusCode(line));
                              */
                         } else if (line.indexOf(":") >= 0) {
-                            response.addHeader
-                                (line.substring(0, line.indexOf(":")).trim(),
-                                line.substring(line.indexOf(":") + 1).trim());
+                            String header =
+                                line.substring(0, line.indexOf(":")).trim();
+                            String value =
+                                line.substring(line.indexOf(":") + 1).trim(); 
+                            response.addHeader(header , value);
+                            if ((header.toLowerCase().equals("content-type"))
+                                && (!value.toLowerCase().startsWith("text"))) {
+                                isBinaryContent = true;
+                            }
                         } else {
                             log("runCGI: bad header line \"" + line + "\"");
                         }
                     }
 
                     //write output
-                    char[] cBuf = new char[1024];
-                    while ((bufRead = commandsStdOut.read(cBuf)) != -1) {
-                        if (servletContainerStdout != null) {
+                    if (isBinaryContent) {
+                        byte[] bBuf = new byte[2048];
+                        OutputStream out = response.getOutputStream();
+                        cgiOutput = proc.getInputStream();
+                        while ((bufRead = cgiOutput.read(bBuf)) != -1) {
                             if (debug >= 4) {
-                                log("runCGI: write(\"" + new String(cBuf, 0, bufRead) + "\")");
+                                log("runCGI: output " + bufRead +
+                                    " bytes of binary data");
                             }
-                            servletContainerStdout.write(cBuf, 0, bufRead);
+                            out.write(bBuf, 0, bufRead);
                         }
-                    }
+                    } else {
+                        commandsStdOut = new BufferedReader
+                            (new InputStreamReader(proc.getInputStream()));
 
-                    if (servletContainerStdout != null) {
-                        servletContainerStdout.flush();
+                        char[] cBuf = new char[1024];
+                        while ((bufRead = commandsStdOut.read(cBuf)) != -1) {
+                            if (servletContainerStdout != null) {
+                                if (debug >= 4) {
+                                    log("runCGI: write(\"" +
+                                        new String(cBuf, 0, bufRead) + "\")");
+                                }
+                                servletContainerStdout.write(cBuf, 0, bufRead);
+                            }
+                        }
+    
+                        if (servletContainerStdout != null) {
+                            servletContainerStdout.flush();
+                        }
                     }
 
                     proc.exitValue(); // Throws exception if alive
@@ -1870,12 +1825,17 @@ public class CGIServlet extends HttpServlet {
 
                 } catch (IllegalThreadStateException e) {
                     try {
-                        Thread.currentThread().sleep(500);
+                        Thread.sleep(500);
                     } catch (InterruptedException ignored) {
                     }
                 }
             } //replacement for Process.waitFor()
-            commandsStdOut.close()  ;
+            // Close the output stream used
+            if (isBinaryContent) {
+                cgiOutput.close();
+            } else {
+                commandsStdOut.close();
+            }
         }
 
         private void sendToLog(BufferedReader rdr) {
@@ -1904,41 +1864,140 @@ public class CGIServlet extends HttpServlet {
         /**
          * Gets a string for input to a POST cgi script
          *
-         * @param  params   Hashtable of query parameters to be passed to
+         * @param  params   ArrayList of query parameters to be passed to
          *                  the CGI script
          * @return          for use as input to the CGI script
          */
 
-        protected String getPostInput(Hashtable params) {
+        protected String getPostInput(ArrayList params) {
             String lineSeparator = System.getProperty("line.separator");
-            Enumeration paramNames = params.keys();
-            StringBuffer postInput = new StringBuffer("");
             StringBuffer qs = new StringBuffer("");
-            if (paramNames != null && paramNames.hasMoreElements()) {
-                while (paramNames.hasMoreElements()) {
-                    String k = (String) paramNames.nextElement();
-                    String v = params.get(k).toString();
-                    if ((k.indexOf("=") < 0) && (v.indexOf("=") < 0)) {
-                        postInput.append(k);
-                        qs.append(k);
-                        postInput.append("=");
-                        qs.append("=");
-                        postInput.append(v);
-                        qs.append(v);
-                        postInput.append(lineSeparator);
-                        qs.append("&");
-                    }
+            for (int i=0; i < params.size(); i++) {
+                NameValuePair nvp = (NameValuePair) this.params.get(i); 
+                String k = nvp.getName();
+                String v = nvp.getValue();
+                if ((k.indexOf("=") < 0) && (v.indexOf("=") < 0)) {
+                    qs.append(k);
+                    qs.append("=");
+                    qs.append(v);
+                    qs.append("&");
                 }
             }
-            qs.append(lineSeparator);
-            return qs.append(postInput.toString()).toString();
+            if (qs.length() > 0) {
+                // Remove last "&"
+                qs.setLength(qs.length() - 1);
+                return qs.toString();
+            } else {
+                return null;
+            }
         }
-
-
-
     } //class CGIRunner
 
+    /**
+     * This is a simple class for storing name-value pairs.
+     * 
+     * TODO: It might be worth moving this to the utils package there is a
+     * wider requirement for this functionality.
+     */
+    protected class NameValuePair {
+        private String name;
+        private String value;
+        
+        NameValuePair(String name, String value) {
+            this.name = name;
+            this.value = value;
+        }
+        
+        protected String getName() {
+            return name;
+        }
+        
+        protected String getValue() {
+            return value;
+        }
+    }
 
+    /**
+     * This is an input stream specifically for reading HTTP headers. It reads
+     * upto and including the two blank lines terminating the headers. It
+     * allows the content to be read using bytes or characters as appropriate.
+     */
+    protected class HTTPHeaderInputStream extends InputStream {
+        private static final int STATE_CHARACTER = 0;
+        private static final int STATE_FIRST_CR = 1;
+        private static final int STATE_FIRST_LF = 2;
+        private static final int STATE_SECOND_CR = 3;
+        private static final int STATE_HEADER_END = 4;
+        
+        private InputStream input;
+        private int state;
+        
+        HTTPHeaderInputStream(InputStream theInput) {
+            input = theInput;
+            state = STATE_CHARACTER;
+        }
 
+        /**
+         * @see java.io.InputStream#read()
+         */
+        public int read() throws IOException {
+            if (state == STATE_HEADER_END) {
+                return -1;
+            }
 
+            int i = input.read();
+
+            // Update the state
+            // State machine looks like this
+            //
+            //    -------->--------
+            //   |      (CR)       |
+            //   |                 |
+            //  CR1--->---         |
+            //   |        |        |
+            //   ^(CR)    |(LF)    |
+            //   |        |        |
+            // CHAR--->--LF1--->--EOH
+            //      (LF)  |  (LF)  |
+            //            |(CR)    ^(LF)
+            //            |        |
+            //          (CR2)-->---
+            
+            if (i == 10) {
+                // LF
+                switch(state) {
+                    case STATE_CHARACTER:
+                        state = STATE_FIRST_LF;
+                        break;
+                    case STATE_FIRST_CR:
+                        state = STATE_FIRST_LF;
+                        break;
+                    case STATE_FIRST_LF:
+                    case STATE_SECOND_CR:
+                        state = STATE_HEADER_END;
+                        break;
+                }
+
+            } else if (i == 13) {
+                // CR
+                switch(state) {
+                    case STATE_CHARACTER:
+                        state = STATE_FIRST_CR;
+                        break;
+                    case STATE_FIRST_CR:
+                        state = STATE_HEADER_END;
+                        break;
+                    case STATE_FIRST_LF:
+                        state = STATE_SECOND_CR;
+                        break;
+                }
+
+            } else {
+                state = STATE_CHARACTER;
+            }
+            
+            return i;            
+        }
+    }  // class HTTPHeaderInputStream
+    
 } //class CGIServlet
