@@ -1,65 +1,18 @@
 /*
-* $Header: /home/cvs/jakarta-tomcat-4.0/catalina/src/share/org/apache/catalina/servlets/HTMLManagerServlet.java,v 1.16 2003/06/14 02:07:46 billbarker Exp $
-* $Revision: 1.16 $
-* $Date: 2003/06/14 02:07:46 $
-*
-* ====================================================================
-*
-* The Apache Software License, Version 1.1
-*
-* Copyright (c) 1999 The Apache Software Foundation.  All rights
-* reserved.
-*
-* Redistribution and use in source and binary forms, with or without
-* modification, are permitted provided that the following conditions
-* are met:
-*
-* 1. Redistributions of source code must retain the above copyright
-*    notice, this list of conditions and the following disclaimer.
-*
-* 2. Redistributions in binary form must reproduce the above copyright
-*    notice, this list of conditions and the following disclaimer in
-*    the documentation and/or other materials provided with the
-*    distribution.
-*
-* 3. The end-user documentation included with the redistribution, if
-*    any, must include the following acknowlegement:
-*       "This product includes software developed by the
-*        Apache Software Foundation (http://www.apache.org/)."
-*    Alternately, this acknowlegement may appear in the software itself,
-*    if and wherever such third-party acknowlegements normally appear.
-*
-* 4. The names "The Jakarta Project", "Tomcat", and "Apache Software
-*    Foundation" must not be used to endorse or promote products derived
-*    from this software without prior written permission. For written
-*    permission, please contact apache@apache.org.
-*
-* 5. Products derived from this software may not be called "Apache"
-*    nor may "Apache" appear in their names without prior written
-*    permission of the Apache Group.
-*
-* THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
-* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
-* OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
-* DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
-* ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
-* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
-* LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
-* USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
-* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
-* OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
-* OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-* SUCH DAMAGE.
-* ====================================================================
-*
-* This software consists of voluntary contributions made by many
-* individuals on behalf of the Apache Software Foundation.  For more
-* information on the Apache Software Foundation, please see
-* <http://www.apache.org/>.
-*
-* [Additional notices, if required by prior licensing conditions]
-*
-*/
+ * Copyright 1999,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
 
 
 package org.apache.catalina.servlets;
@@ -71,7 +24,6 @@ import java.io.StringWriter;
 import java.net.URL;
 import java.net.MalformedURLException;
 import java.text.MessageFormat;
-import java.util.Date;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
@@ -85,7 +37,6 @@ import org.apache.catalina.Host;
 import org.apache.catalina.util.ServerInfo;
 import org.apache.commons.fileupload.FileItem;
 import org.apache.commons.fileupload.DiskFileUpload;
-import org.apache.commons.fileupload.FileUploadException;
 
 /**
 * Servlet that enables remote management of the web applications installed
@@ -106,7 +57,7 @@ import org.apache.commons.fileupload.FileUploadException;
 * @author Bip Thelin
 * @author Malcolm Edgar
 * @author Glenn L. Nielsen
-* @version $Revision: 1.16 $, $Date: 2003/06/14 02:07:46 $
+* @version $Revision: 1.18 $, $Date: 2004/08/26 21:38:13 $
 * @see ManagerServlet
 */
 
@@ -659,7 +610,7 @@ public final class HTMLManagerServlet extends ManagerServlet {
         "  </td>\n" +
         " </tr>\n" +
         "</table>\n" +
-        "<hr size=\"1\" noshade\"\">\n" +
+        "<hr size=\"1\" noshade=\"noshade\">\n" +
         "<table cellspacing=\"4\" width=\"100%\" border=\"0\">\n" +
         " <tr>\n" +
         "  <td class=\"page-title\" bordercolor=\"#000000\" " +
@@ -861,7 +812,7 @@ public final class HTMLManagerServlet extends ManagerServlet {
         "\n";
 
     private static final String HTML_TAIL_SECTION =
-        "<hr size=\"1\" noshade\"\">\n" +
+        "<hr size=\"1\" noshade=\"noshade\">\n" +
         "<center><font size=\"-1\" color=\"#525D76\">\n" +
         " <em>Copyright &copy; 1999-2002, Apache Software Foundation</em>" +
         "</font></center>\n" +
