@@ -1,80 +1,29 @@
 /*
- * JDBCStore.java
- * $Header: /home/cvs/jakarta-tomcat-4.0/catalina/src/share/org/apache/catalina/session/JDBCStore.java,v 1.11 2003/03/12 01:19:03 glenn Exp $
- * $Revision: 1.11 $
- * $Date: 2003/03/12 01:19:03 $
- *
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Tomcat", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
- *
- * [Additional notices, if required by prior licensing conditions]
- *
+ * Copyright 1999,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 package org.apache.catalina.session;
 
 import java.io.InputStream;
-import java.io.OutputStream;
 import java.io.BufferedInputStream;
 import java.io.BufferedOutputStream;
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
-import java.io.InputStream;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
-import java.io.ObjectStreamClass;
 import java.sql.Connection;
 import java.sql.DriverManager;
 import java.sql.PreparedStatement;
@@ -94,7 +43,7 @@ import org.apache.catalina.util.CustomObjectInputStream;
  * saved are still subject to being expired based on inactivity.
  *
  * @author Bip Thelin
- * @version $Revision: 1.11 $, $Date: 2003/03/12 01:19:03 $
+ * @version $Revision: 1.14 $, $Date: 2004/08/26 21:39:08 $
  */
 
 public class JDBCStore
@@ -204,6 +153,11 @@ public class JDBCStore
      */
     protected PreparedStatement preparedLoadSql = null;
 
+    /**
+     * Variable to hold the <code>processExpires()</code> prepared statement.
+     */
+    protected PreparedStatement preparedExpiresSql = null;
+
     // ------------------------------------------------------------- Properties
 
     /**
@@ -470,6 +424,7 @@ public class JDBCStore
                 keys = (String[]) tmpkeys.toArray(new String[tmpkeys.size()]);
             } catch(SQLException e) {
                 log(sm.getString(getStoreName()+".SQLException", e));
+                keys = new String[0];
             } finally {
                 try {
                     if(rst != null) {
@@ -482,7 +437,7 @@ public class JDBCStore
                 release(_conn);
             }
         }
-
+        
         return(keys);
     }
 
@@ -632,6 +587,11 @@ public class JDBCStore
      * @exception IOException if an input/output error occurs
      */
     public void remove(String id) throws IOException {
+
+        if (id == null) {
+            return;
+        }
+
         String removeSql =
             "DELETE FROM " + sessionTable + " WHERE " + sessionIdCol +
             " = ?  AND " + sessionAppCol + " = ?";
@@ -744,7 +704,7 @@ public class JDBCStore
                 preparedSaveSql.setBinaryStream(3, in, size);
                 preparedSaveSql.setString(4, session.isValid()?"1":"0");
                 preparedSaveSql.setInt(5, session.getMaxInactiveInterval());
-                preparedSaveSql.setLong(6, session.getLastAccessedTime());
+                preparedSaveSql.setLong(6, ((StandardSession)session).getLastUsedTime());
                 preparedSaveSql.execute();
             } catch(SQLException e) {
                 log(sm.getString(getStoreName()+".SQLException", e));
@@ -770,6 +730,101 @@ public class JDBCStore
 
     // --------------------------------------------------------- Protected Methods
 
+    /**
+     * Called by our background reaper thread to check if Sessions
+     * saved in our store are subject of being expired. If so expire
+     * the Session and remove it from the Store.
+     *
+     */
+    protected void processExpires() {
+
+        if(!started) {
+            return;
+        }
+
+        String expiresSql =
+            "SELECT " + sessionIdCol + " FROM " + sessionTable +
+            " WHERE " + sessionAppCol + " = ? AND ? > (" +
+            sessionLastAccessedCol + " + (" + sessionMaxInactiveCol +
+            "*1000))";
+
+        ResultSet rst = null;
+        String keys[] = null;
+        long timeNow = System.currentTimeMillis();
+
+        synchronized(this) {
+            Connection _conn = getConnection();
+
+            if(_conn == null) {
+                return;
+            }
+
+            try {
+                if(preparedExpiresSql == null) {
+                    preparedExpiresSql = _conn.prepareStatement(expiresSql);
+                }
+
+                preparedExpiresSql.setString(1, getName());
+                preparedExpiresSql.setLong(2,timeNow);
+                rst = preparedExpiresSql.executeQuery();
+                ArrayList tmpkeys = new ArrayList();
+                if (rst != null) {
+                    while(rst.next()) {
+                        tmpkeys.add(rst.getString(1));
+                    }
+                }
+                keys = (String[]) tmpkeys.toArray(new String[tmpkeys.size()]);
+            } catch(SQLException e) {
+                log(sm.getString(getStoreName()+".SQLException", e));
+                keys = new String[0];
+            } finally {
+                try {
+                    if(rst != null) {
+                        rst.close();
+                    }
+                } catch(SQLException e) {
+                    ;
+                }
+
+                release(_conn);
+            }
+        }
+
+        for (int i = 0; i < keys.length; i++) {
+            try {
+                StandardSession session = (StandardSession) load(keys[i]);
+                if (session == null) {
+                    continue;
+                }
+                if (!session.isValid()) {
+                    continue;
+                }
+                int maxInactiveInterval = session.getMaxInactiveInterval();
+                if (maxInactiveInterval < 0) {
+                    continue;
+                }
+                int timeIdle = // Truncate, do not round up
+                    (int) ((timeNow - ((StandardSession)session).getLastUsedTime()) / 1000L);
+                if (timeIdle >= maxInactiveInterval) {
+                    if ( ( (PersistentManagerBase) manager).isLoaded( keys[i] )) {
+                        // recycle old backup session
+                        session.recycle();
+                    } else {
+                        // expire swapped out session
+                        session.expire();
+                    }
+                    remove(session.getId());
+                }
+            } catch (IOException e) {
+                log (e.toString());
+                e.printStackTrace();
+            } catch (ClassNotFoundException e) {
+                log (e.toString());
+                e.printStackTrace();
+            }
+        }
+    }
+
     /**
      * Check the connection associated with this store, if it's
      * <code>null</code> or closed try to reopen it.
@@ -884,6 +939,14 @@ public class JDBCStore
                 }
             }
 
+            if( preparedExpiresSql != null ) {
+                try {
+                    preparedExpiresSql.close();
+                } catch (SQLException e) {
+                    ;
+                }
+            }
+
             try {
                 conn.close();
             } catch (SQLException e) {
@@ -896,6 +959,7 @@ public class JDBCStore
             this.preparedClearSql = null;
             this.preparedRemoveSql = null;
             this.preparedLoadSql = null;
+            this.preparedExpiresSql = null;
             this.conn = null;
         }
     }
