@@ -1,64 +1,17 @@
 /*
- * $Header: /home/cvs/jakarta-tomcat-4.0/catalina/src/share/org/apache/catalina/session/PersistentManagerBase.java,v 1.17 2003/12/11 23:52:04 markt Exp $
- * $Revision: 1.17 $
- * $Date: 2003/12/11 23:52:04 $
- *
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Tomcat", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
- *
- * [Additional notices, if required by prior licensing conditions]
- *
+ * Copyright 1999,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 
@@ -67,6 +20,7 @@ package org.apache.catalina.session;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.io.IOException;
+import java.util.Hashtable;
 import org.apache.catalina.Container;
 import org.apache.catalina.Context;
 import org.apache.catalina.Lifecycle;
@@ -87,7 +41,7 @@ import org.apache.catalina.util.LifecycleSupport;
  * <code>stop()</code> methods of this class at the correct times.
  *
  * @author Craig R. McClanahan
- * @version $Revision: 1.17 $ $Date: 2003/12/11 23:52:04 $
+ * @version $Revision: 1.19 $ $Date: 2004/08/26 21:39:08 $
  */
 
 public abstract class PersistentManagerBase
@@ -134,6 +88,20 @@ public abstract class PersistentManagerBase
     private boolean started = false;
 
 
+    /**
+     * Map of Sessions which are not in swap but have
+     * been requested at least once.
+     *
+     * This is to improve performance when a JSESSIONID
+     * is sent by the client but no longer exists as a
+     * session so that the Store doesn't get banged on
+     * multiple times per request.
+     *
+     * This is a Hashtable to ensure use is thread safe.
+     *
+     */
+    private Hashtable sessionSwapIgnore = new Hashtable();
+
     /**
      * The background thread.
      */
@@ -691,6 +659,10 @@ public abstract class PersistentManagerBase
         if (store == null)
             return null;
 
+        if (sessionSwapIgnore.contains(id)) {
+            return null;
+        }
+
         Session session = null;
         try {
             session = store.load(id);
@@ -700,14 +672,17 @@ public abstract class PersistentManagerBase
                 (sm.getString("persistentManager.deserializeError", id, e));
         }
 
-        if (session == null)
+        if (session == null) {
+            sessionSwapIgnore.put(id,id);
             return (null);
+        }
 
         if (!session.isValid()
                 || isSessionStale(session, System.currentTimeMillis())) {
             log("session swapped in is invalid or expired");
             session.expire();
             store.remove(id);
+            sessionSwapIgnore.put(id,id);
             return (null);
         }
 
@@ -762,6 +737,7 @@ public abstract class PersistentManagerBase
 
         try {
             store.save(session);
+            sessionSwapIgnore.remove(session.getId());
         } catch (IOException e) {
             log(sm.getString
                 ("persistentManager.serializeError", session.getId(), e));
@@ -938,8 +914,9 @@ public abstract class PersistentManagerBase
 
         int maxInactiveInterval = session.getMaxInactiveInterval();
         if (maxInactiveInterval >= 0) {
+            long lastAccessed = ((StandardSession)session).getLastUsedTime();
             int timeIdle = // Truncate, do not round up
-                (int) ((timeNow - session.getLastAccessedTime()) / 1000L);
+                (int) ((timeNow - lastAccessed) / 1000L);
             if (timeIdle >= maxInactiveInterval)
                 return true;
         }
@@ -994,8 +971,9 @@ public abstract class PersistentManagerBase
                 StandardSession session = (StandardSession) sessions[i];
                 if (!session.isValid())
                     continue;
+                long lastAccessed = ((StandardSession)session).getLastUsedTime();
                 int timeIdle = // Truncate, do not round up
-                    (int) ((timeNow - session.getLastAccessedTime()) / 1000L);
+                    (int) ((timeNow - lastAccessed) / 1000L);
                 if (timeIdle > maxIdleSwap && timeIdle > minIdleSwap) {
                     if (debug > 1)
                         log(sm.getString
@@ -1036,15 +1014,16 @@ public abstract class PersistentManagerBase
         long timeNow = System.currentTimeMillis();
 
         for (int i = 0; i < sessions.length && toswap > 0; i++) {
+            StandardSession session = (StandardSession)sessions[i];
             int timeIdle = // Truncate, do not round up
-                (int) ((timeNow - sessions[i].getLastAccessedTime()) / 1000L);
+                (int) ((timeNow - session.getLastUsedTime()) / 1000L);
             if (timeIdle > minIdleSwap) {
                 if(debug > 1)
                     log(sm.getString
                         ("persistentManager.swapTooManyActive",
-                         sessions[i].getId(), new Integer(timeIdle)));
+                         session.getId(), new Integer(timeIdle)));
                 try {
-                    swapOut(sessions[i]);
+                    swapOut(session);
                 } catch (IOException e) {
                     ;   // This is logged in writeSession()
                 }
@@ -1073,7 +1052,7 @@ public abstract class PersistentManagerBase
                 if (!session.isValid())
                     continue;
                 int timeIdle = // Truncate, do not round up
-                    (int) ((timeNow - session.getLastAccessedTime()) / 1000L);
+                    (int) ((timeNow - session.getLastUsedTime()) / 1000L);
                 if (timeIdle > maxIdleBackup) {
                     if (debug > 1)
                         log(sm.getString
@@ -1160,6 +1139,7 @@ public abstract class PersistentManagerBase
             threadSleep();
             processExpires();
             processPersistenceChecks();
+            sessionSwapIgnore.clear();
         }
 
     }
