@@ -1,64 +1,17 @@
 /*
- * $Header: /home/cvs/jakarta-tomcat-4.0/catalina/src/share/org/apache/catalina/startup/Catalina.java,v 1.51 2002/10/24 02:42:03 jfarcand Exp $
- * $Revision: 1.51 $
- * $Date: 2002/10/24 02:42:03 $
- *
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Tomcat", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
- *
- * [Additional notices, if required by prior licensing conditions]
- *
+ * Copyright 1999,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 
@@ -69,17 +22,13 @@ import java.io.File;
 import java.io.FileInputStream;
 import java.io.IOException;
 import java.io.OutputStream;
-import java.lang.reflect.InvocationTargetException;
-import java.lang.reflect.Constructor;
 import java.net.Socket;
 import java.security.Security;
-import java.util.Stack;
 import org.apache.catalina.Container;
 import org.apache.catalina.Lifecycle;
 import org.apache.catalina.LifecycleException;
-import org.apache.catalina.LifecycleListener;
 import org.apache.catalina.Server;
-import org.apache.catalina.Loader;
+import org.apache.catalina.core.StandardServer;
 import org.apache.commons.digester.Digester;
 import org.apache.commons.digester.Rule;
 import org.apache.tomcat.util.log.SystemLogHandler;
@@ -100,7 +49,7 @@ import org.xml.sax.InputSource;
  * </u>
  *
  * @author Craig R. McClanahan
- * @version $Revision: 1.51 $ $Date: 2002/10/24 02:42:03 $
+ * @version $Revision: 1.56 $ $Date: 2004/08/26 21:41:12 $
  */
 
 public class Catalina {
@@ -278,6 +227,7 @@ public class Catalina {
 
         // Initialize the digester
         Digester digester = new Digester();
+        digester.setClassLoader(StandardServer.class.getClassLoader());
         if (debug)
             digester.setDebug(999);
         digester.setValidating(false);
@@ -437,23 +387,6 @@ public class Catalina {
      */
     protected void start() {
 
-        // Create and execute our Digester
-        Digester digester = createStartDigester();
-        File file = configFile();
-        try {
-            InputSource is =
-                new InputSource("file://" + file.getAbsolutePath());
-            FileInputStream fis = new FileInputStream(file);
-            is.setByteStream(fis);
-            digester.push(this);
-            digester.parse(is);
-            fis.close();
-        } catch (Exception e) {
-            System.out.println("Catalina.start: " + e);
-            e.printStackTrace(System.out);
-            System.exit(1);
-        }
-
         // Setting additional variables
         if (!useNaming) {
             System.setProperty("catalina.useNaming", "false");
@@ -475,6 +408,24 @@ public class Catalina {
             }
         }
 
+        // Create and execute our Digester
+        Digester digester = createStartDigester();
+        File file = configFile();
+        try {
+            InputSource is =
+                new InputSource("file://" + file.getAbsolutePath());
+            FileInputStream fis = new FileInputStream(file);
+            is.setByteStream(fis);
+            digester.push(this);
+            digester.parse(is);
+            fis.close();
+        } catch (Exception e) {
+            System.out.println("Catalina.start using "
+                               + configFile() + ": " + e);
+            e.printStackTrace(System.out);
+            System.exit(1);
+        }
+
         // If a SecurityManager is being used, set properties for
         // checkPackageAccess() and checkPackageDefinition
         if( System.getSecurityManager() != null ) {
