@@ -1,64 +1,17 @@
 /*
- * $Header: /home/cvs/jakarta-tomcat-4.0/catalina/src/share/org/apache/catalina/startup/ContextConfig.java,v 1.67 2002/10/29 04:17:25 billbarker Exp $
- * $Revision: 1.67 $
- * $Date: 2002/10/29 04:17:25 $
- *
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999-2001 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Tomcat", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
- *
- * [Additional notices, if required by prior licensing conditions]
- *
+ * Copyright 1999-2001,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */
 
 
@@ -70,19 +23,14 @@ import java.io.FileInputStream;
 import java.io.FileNotFoundException;
 import java.io.InputStream;
 import java.io.IOException;
-import java.lang.reflect.InvocationTargetException;
-import java.lang.reflect.Method;
 import java.net.JarURLConnection;
-import java.net.MalformedURLException;
 import java.net.URL;
-import java.util.ArrayList;
 import java.util.Enumeration;
 import java.util.HashSet;
 import java.util.Iterator;
 import java.util.MissingResourceException;
 import java.util.ResourceBundle;
 import java.util.Set;
-import java.util.Stack;
 import java.util.jar.JarEntry;
 import java.util.jar.JarFile;
 import javax.naming.NamingException;
@@ -95,9 +43,7 @@ import org.apache.catalina.Authenticator;
 import org.apache.catalina.Connector;
 import org.apache.catalina.Container;
 import org.apache.catalina.Context;
-import org.apache.catalina.DefaultContext;
 import org.apache.catalina.Engine;
-import org.apache.catalina.Globals;
 import org.apache.catalina.Host;
 import org.apache.catalina.Lifecycle;
 import org.apache.catalina.LifecycleEvent;
@@ -109,20 +55,12 @@ import org.apache.catalina.Valve;
 import org.apache.catalina.Wrapper;
 import org.apache.catalina.core.ContainerBase;
 import org.apache.catalina.core.StandardContext;
-import org.apache.catalina.deploy.ApplicationParameter;
-import org.apache.catalina.deploy.ContextEjb;
-import org.apache.catalina.deploy.ContextEnvironment;
-import org.apache.catalina.deploy.ContextLocalEjb;
-import org.apache.catalina.deploy.ContextResource;
-import org.apache.catalina.deploy.ContextResourceLink;
 import org.apache.catalina.deploy.ErrorPage;
 import org.apache.catalina.deploy.FilterDef;
 import org.apache.catalina.deploy.FilterMap;
 import org.apache.catalina.deploy.LoginConfig;
 import org.apache.catalina.deploy.SecurityConstraint;
-import org.apache.catalina.loader.Extension;
 import org.apache.catalina.util.StringManager;
-import org.apache.catalina.valves.ValveBase;
 import org.apache.commons.digester.Digester;
 import org.xml.sax.InputSource;
 import org.xml.sax.SAXParseException;
@@ -133,7 +71,7 @@ import org.xml.sax.SAXParseException;
  * of that Context, and the associated defined servlets.
  *
  * @author Craig R. McClanahan
- * @version $Revision: 1.67 $ $Date: 2002/10/29 04:17:25 $
+ * @version $Revision: 1.71 $ $Date: 2004/09/06 18:51:37 $
  */
 
 public final class ContextConfig
@@ -280,6 +218,7 @@ public final class ContextConfig
                 webDigester.clear();
                 webDigester.push(context);
                 webDigester.parse(is);
+                webDigester.push(null);
             } catch (SAXParseException e) {
                 log(sm.getString("contextConfig.applicationParse"), e);
                 log(sm.getString("contextConfig.applicationPosition",
@@ -546,6 +485,7 @@ public final class ContextConfig
                 webDigester.clear();
                 webDigester.push(context);
                 webDigester.parse(is);
+                webDigester.push(null);
             } catch (SAXParseException e) {
                 log(sm.getString("contextConfig.defaultParse"), e);
                 log(sm.getString("contextConfig.defaultPosition",
@@ -708,13 +648,14 @@ public final class ContextConfig
         }
 
         // Removing application parameters
+        /*
         ApplicationParameter[] applicationParameters =
             context.findApplicationParameters();
         for (i = 0; i < applicationParameters.length; i++) {
             context.removeApplicationParameter
                 (applicationParameters[i].getName());
         }
-
+        */
         // Removing security constraints
         SecurityConstraint[] securityConstraints = context.findConstraints();
         for (i = 0; i < securityConstraints.length; i++) {
@@ -780,7 +721,7 @@ public final class ContextConfig
         for (i = 0; i < parameters.length; i++) {
             context.removeParameter(parameters[i]);
         }
-
+        
         // Removing resource env refs
         /*
         String[] resourceEnvRefs = context.findResourceEnvRefs();
@@ -925,6 +866,16 @@ public final class ContextConfig
             }
             // FIXME - Closing the JAR file messes up the class loader???
             //            jarFile.close();
+        } catch (IOException ioe) {
+            File tmp = new File(System.getProperty("java.io.tmpdir"));
+            if (!tmp.canWrite()) {
+                throw new ServletException
+                    (sm.getString("contextConfig.noTempDir"), ioe);
+            } else {
+                throw new ServletException
+                    (sm.getString("contextConfig.tldJarIOException",
+                                  resourcePath), ioe);
+            }
         } catch (Exception e) {
             if (name == null) {
                 throw new ServletException
@@ -975,6 +926,8 @@ public final class ContextConfig
             tldDigester.clear();
             tldDigester.push(context);
             tldDigester.parse(resourceStream);
+            tldDigester.push(null);
+
         }
 
     }
