@@ -1,64 +1,17 @@
 /*
- * $Header: /home/cvs/jakarta-tomcat-4.0/catalina/src/test/org/apache/naming/resources/BaseDirContextTestCase.java,v 1.3 2001/10/21 22:03:34 remm Exp $
- * $Revision: 1.3 $
- * $Date: 2001/10/21 22:03:34 $
- *
- * ====================================================================
- *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999 The Apache Software Foundation.  All rights 
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:  
- *       "This product includes software developed by the 
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Tomcat", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written 
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
- *
- * [Additional notices, if required by prior licensing conditions]
- *
+ * Copyright 1999,2004 The Apache Software Foundation.
+ * 
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ * 
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ * 
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
  */ 
 
 
@@ -75,9 +28,7 @@ import javax.naming.directory.Attribute;
 import javax.naming.directory.Attributes;
 import javax.naming.directory.DirContext;
 
-import junit.framework.Test;
 import junit.framework.TestCase;
-import junit.framework.TestSuite;
 
 
 /**
@@ -105,7 +56,7 @@ import junit.framework.TestSuite;
  * </ul>
  *
  * @author Craig R. McClanahan
- * @version $Revision: 1.3 $ $Date: 2001/10/21 22:03:34 $
+ * @version $Revision: 1.5 $ $Date: 2004/08/26 21:46:56 $
  */
 
 public abstract class BaseDirContextTestCase extends TestCase {
@@ -247,8 +198,8 @@ public abstract class BaseDirContextTestCase extends TestCase {
             // Look up the WEB-INF entry
             Object webInfEntry = context.lookup("WEB-INF");
             assertNotNull("Found WEB-INF entry", webInfEntry);
-            assert("WEB-INF entry is a DirContext",
-                   webInfEntry instanceof DirContext);
+            assertTrue("WEB-INF entry is a DirContext",
+                       webInfEntry instanceof DirContext);
             DirContext webInfContext = (DirContext) webInfEntry;
 
             // Check the contents of the WEB-INF context directly
@@ -303,8 +254,8 @@ public abstract class BaseDirContextTestCase extends TestCase {
             // Look up the WEB-INF entry
             Object webInfEntry = context.lookup("WEB-INF");
             assertNotNull("Found WEB-INF entry", webInfEntry);
-            assert("WEB-INF entry is a DirContext",
-                   webInfEntry instanceof DirContext);
+            assertTrue("WEB-INF entry is a DirContext",
+                       webInfEntry instanceof DirContext);
             DirContext webInfContext = (DirContext) webInfEntry;
 
             // Check the bindings of the WEB-INF context directly
@@ -353,20 +304,20 @@ public abstract class BaseDirContextTestCase extends TestCase {
         while (ne.hasMore()) {
 
             Object next = ne.next();
-            assert("list() returns NameClassPair instances",
-                   next instanceof NameClassPair);
+            assertTrue("list() returns NameClassPair instances",
+                       next instanceof NameClassPair);
             NameClassPair ncp = (NameClassPair) next;
 
-            assert("Name '" + ncp.getName() + "' is expected",
-                   isListed(ncp.getName(), list));
+            assertTrue("Name '" + ncp.getName() + "' is expected",
+                       isListed(ncp.getName(), list));
 
             if (isDirContext(ncp.getName())) {
-                assert("Class '" + ncp.getClassName() + "' is '" +
-                       contextClassName + "'",
-                       contextClassName.equals(ncp.getClassName()));
+                assertTrue("Class '" + ncp.getClassName() + "' is '" +
+                           contextClassName + "'",
+                           contextClassName.equals(ncp.getClassName()));
             }
 
-            assert("Relative is 'true'", ncp.isRelative());
+            assertTrue("Relative is 'true'", ncp.isRelative());
 
         }
 
@@ -391,30 +342,30 @@ public abstract class BaseDirContextTestCase extends TestCase {
         while (ne.hasMore()) {
 
             Object next = ne.next();
-            assert("listBindings() returns Binding instances",
-                   next instanceof Binding);
+            assertTrue("listBindings() returns Binding instances",
+                       next instanceof Binding);
             Binding b = (Binding) next;
 
-            assert("Name '" + b.getName() + "' is expected",
-                   isListed(b.getName(), list));
+            assertTrue("Name '" + b.getName() + "' is expected",
+                       isListed(b.getName(), list));
 
             if (isDirContext(b.getName())) {
-                assert("Class '" + b.getClassName() + "' is '" +
-                       contextClassName + "'",
-                       contextClassName.equals(b.getClassName()));
+                assertTrue("Class '" + b.getClassName() + "' is '" +
+                           contextClassName + "'",
+                           contextClassName.equals(b.getClassName()));
             }
 
-            assert("Relative is 'true'", b.isRelative());
+            assertTrue("Relative is 'true'", b.isRelative());
 
             Object object = b.getObject();
             assertNotNull("Name '" + b.getName() + "' has a non-null object",
                           object);
             if (b.getName().equals("web.xml")) {
-                assert("Entry '" + b.getName() + "' is a Resource",
-                       object instanceof Resource);
+                assertTrue("Entry '" + b.getName() + "' is a Resource",
+                           object instanceof Resource);
             } else {
-                assert("Entry '" + b.getName() + "' is a DirContext",
-                       object instanceof DirContext);
+                assertTrue("Entry '" + b.getName() + "' is a DirContext",
+                           object instanceof DirContext);
             }
 
         }
@@ -445,36 +396,36 @@ public abstract class BaseDirContextTestCase extends TestCase {
         while (ne.hasMore()) {
 
             Object next = ne.next();
-            assert("getAll() returns Attribute instances",
-                   next instanceof Attribute);
+            assertTrue("getAll() returns Attribute instances",
+                       next instanceof Attribute);
             Attribute attr = (Attribute) next;
             String name = attr.getID();
             int index = getIndex(name, webInfAttrs);
-            assert("WEB-INF attribute '" + name + "' is expected",
-                   index >= 0);
+            assertTrue("WEB-INF attribute '" + name + "' is expected",
+                       index >= 0);
             Object value = attr.get();
             assertNotNull("get() returned non-null", value);
 
             if (name.equals("creationdate")) {
-                assert("Creation date is a date",
-                       value instanceof Date);
-                assert("Creation date equals " + creationDate,
-                       creationDate.equals((Date) value));
+                assertTrue("Creation date is a date",
+                           value instanceof Date);
+                assertTrue("Creation date equals " + creationDate,
+                           creationDate.equals((Date) value));
             } else if (name.equals("displayname")) {
-                assert("Display name is a string",
-                       value instanceof String);
-                assert("Display name equals " + displayName,
-                       displayName.equals((String) value));
+                assertTrue("Display name is a string",
+                           value instanceof String);
+                assertTrue("Display name equals " + displayName,
+                           displayName.equals((String) value));
             } else if (name.equals("getcontentlength")) {
-                assert("Content length is a long",
-                       value instanceof Long);
-                assert("Content length equals " + contentLength,
-                       contentLength == ((Long) value).longValue());
+                assertTrue("Content length is a long",
+                           value instanceof Long);
+                assertTrue("Content length equals " + contentLength,
+                           contentLength == ((Long) value).longValue());
             } else if (name.equals("getlastmodified")) {
-                assert("Last modified date is a date",
-                       value instanceof Date);
-                assert("Last modified date is " + lastModifiedDate,
-                       lastModifiedDate.equals((Date) value));
+                assertTrue("Last modified date is a date",
+                           value instanceof Date);
+                assertTrue("Last modified date is " + lastModifiedDate,
+                           lastModifiedDate.equals((Date) value));
             }
 
         }
@@ -505,36 +456,36 @@ public abstract class BaseDirContextTestCase extends TestCase {
         while (ne.hasMore()) {
 
             Object next = ne.next();
-            assert("getAll() returns Attribute instances",
-                   next instanceof Attribute);
+            assertTrue("getAll() returns Attribute instances",
+                       next instanceof Attribute);
             Attribute attr = (Attribute) next;
             String name = attr.getID();
             int index = getIndex(name, webXmlAttrs);
-            assert("WEB-INF/web.xml attribute '" + name + "' is expected",
-                   index >= 0);
+            assertTrue("WEB-INF/web.xml attribute '" + name + "' is expected",
+                       index >= 0);
             Object value = attr.get();
             assertNotNull("get() returned non-null", value);
 
             if (name.equals("creationdate")) {
-                assert("Creation date is a date",
-                       value instanceof Date);
-                assert("Creation date equals " + creationDate,
-                       creationDate.equals((Date) value));
+                assertTrue("Creation date is a date",
+                           value instanceof Date);
+                assertTrue("Creation date equals " + creationDate,
+                           creationDate.equals((Date) value));
             } else if (name.equals("displayname")) {
-                assert("Display name is a string",
-                       value instanceof String);
-                assert("Display name equals " + displayName,
-                       displayName.equals((String) value));
+                assertTrue("Display name is a string",
+                           value instanceof String);
+                assertTrue("Display name equals " + displayName,
+                           displayName.equals((String) value));
             } else if (name.equals("getcontentlength")) {
-                assert("Content length is a long",
-                       value instanceof Long);
-                assert("Content length equals " + contentLength,
-                       contentLength == ((Long) value).longValue());
+                assertTrue("Content length is a long",
+                           value instanceof Long);
+                assertTrue("Content length equals " + contentLength,
+                           contentLength == ((Long) value).longValue());
             } else if (name.equals("getlastmodified")) {
-                assert("Last modified date is a date",
-                       value instanceof Date);
-                assert("Last modified date is " + lastModifiedDate,
-                       lastModifiedDate.equals((Date) value));
+                assertTrue("Last modified date is a date",
+                           value instanceof Date);
+                assertTrue("Last modified date is " + lastModifiedDate,
+                           lastModifiedDate.equals((Date) value));
             }
 
         }
