@@ -1,61 +1,18 @@
 /*
- * ====================================================================
- * 
- * The Apache Software License, Version 1.1
+ *  Copyright 1999-2004 The Apache Software Foundation
  *
- * Copyright (c) 1999 The Apache Software Foundation.  All rights 
- * reserved.
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
+ *      http://www.apache.org/licenses/LICENSE-2.0
  *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:  
- *       "This product includes software developed by the 
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Tomcat", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written 
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
- *
- * [Additional notices, if required by prior licensing conditions]
- *
- */ 
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */
 
 package org.apache.coyote.http11;
 
@@ -119,19 +76,27 @@ public class Http11Processor implements Processor, ActionHook {
      * Default constructor.
      */
     public Http11Processor() {
+        this(Constants.DEFAULT_HTTP_HEADER_BUFFER_SIZE);
+    }
+
+
+    public Http11Processor(int headerBufferSize) {
 
         request = new Request();
-        inputBuffer = new InternalInputBuffer(request);
+        inputBuffer = new InternalInputBuffer(request, headerBufferSize);
         request.setInputBuffer(inputBuffer);
 
         response = new Response();
         response.setHook(this);
-        outputBuffer = new InternalOutputBuffer(response);
+        outputBuffer = new InternalOutputBuffer(response, headerBufferSize);
         response.setOutputBuffer(outputBuffer);
         request.setResponse(response);
 
         initializeFilters();
 
+        // Cause loading of HexUtils
+        int foo = HexUtils.DEC[0];
+
     }
 
 
@@ -205,6 +170,12 @@ public class Http11Processor implements Processor, ActionHook {
     protected boolean contentDelimitation = true;
 
 
+    /**
+     * Is there an expectation ?
+     */
+    protected boolean expectation = false;
+
+
     /**
      * List of restricted user agents.
      */
@@ -933,19 +904,15 @@ public class Http11Processor implements Processor, ActionHook {
             // Send a 100 status back if it makes sense (response not committed
             // yet, and client specified an expectation for 100-continue)
 
-            if ((response.isCommitted()) || (!http11))
+            if ((response.isCommitted()) || !expectation)
                 return;
 
-            MessageBytes expectMB = 
-                request.getMimeHeaders().getValue("expect");
-            if ((expectMB != null)
-                && (expectMB.indexOfIgnoreCase("100-continue", 0) != -1)) {
-                try {
-                    outputBuffer.sendAck();
-                } catch (IOException e) {
-                    // Set error flag
-                    error = true;
-                }
+            inputBuffer.setSwallowInput(true);
+            try {
+                outputBuffer.sendAck();
+            } catch (IOException e) {
+                // Set error flag
+                error = true;
             }
 
         } else if (actionCode == ActionCode.ACTION_CLIENT_FLUSH) {
@@ -1127,6 +1094,7 @@ public class Http11Processor implements Processor, ActionHook {
         http11 = true;
         http09 = false;
         contentDelimitation = false;
+        expectation = false;
         if (sslSupport != null) {
             request.scheme().setString("https");
         }
@@ -1171,6 +1139,15 @@ public class Http11Processor implements Processor, ActionHook {
             }
         }
 
+        MessageBytes expectMB = null;
+        if (http11)
+            expectMB = request.getMimeHeaders().getValue("expect");
+        if ((expectMB != null)
+            && (expectMB.indexOfIgnoreCase("100-continue", 0) != -1)) {
+            inputBuffer.setSwallowInput(false);
+            expectation = true;
+        }
+
         // Check user-agent header
         if ((restrictedUserAgents != null) && ((http11) || (keepAlive))) {
             MessageBytes userAgentValueMB =  
@@ -1219,7 +1196,7 @@ public class Http11Processor implements Processor, ActionHook {
         InputFilter[] inputFilters = inputBuffer.getFilters();
 
         // Parse content-length header
-        int contentLength = request.getContentLength();
+        long contentLength = request.getContentLengthLong();
         if (contentLength >= 0) {
             inputBuffer.addActiveFilter
                 (inputFilters[Constants.IDENTITY_FILTER]);
@@ -1368,9 +1345,12 @@ public class Http11Processor implements Processor, ActionHook {
      */
     private boolean isCompressable() {
 
+        // Nope Compression could works in HTTP 1.0 also
+        // cf: mod_deflate
+        
         // Compression only since HTTP 1.1
-        if (! http11)
-            return false;
+        // if (! http11)
+        //    return false;
 
         // Check if browser support gzip encoding
         MessageBytes acceptEncodingMB = 
@@ -1494,6 +1474,9 @@ public class Http11Processor implements Processor, ActionHook {
                     (outputFilters[Constants.CHUNKED_FILTER]);
                 contentDelimitation = true;
                 response.addHeader("Transfer-Encoding", "chunked");
+            } else {
+                outputBuffer.addActiveFilter
+                    (outputFilters[Constants.IDENTITY_FILTER]);
             }
         }
 
