@@ -1,61 +1,19 @@
 /*
- * ====================================================================
+ *  Copyright 1999-2004 The Apache Software Foundation
  *
- * The Apache Software License, Version 1.1
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
  *
- * Copyright (c) 1999 The Apache Software Foundation.  All rights 
- * reserved.
+ *      http://www.apache.org/licenses/LICENSE-2.0
  *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:  
- *       "This product includes software developed by the 
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Tomcat", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written 
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
- *
- * [Additional notices, if required by prior licensing conditions]
- *
- */ 
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */
+
 package org.apache.coyote.http11;
 
 import java.io.IOException;
@@ -63,6 +21,7 @@ import java.io.InputStream;
 import java.io.OutputStream;
 import java.net.InetAddress;
 import java.net.Socket;
+import java.net.URLEncoder;
 import java.util.Enumeration;
 import java.util.Hashtable;
 
@@ -117,14 +76,8 @@ public class Http11Protocol implements ProtocolHandler, MBeanRegistration
     public void setAttribute( String name, Object value ) {
         if( log.isTraceEnabled())
             log.trace(sm.getString("http11protocol.setattribute", name, value));
+
         attributes.put(name, value);
-/*
-        if ("maxKeepAliveRequests".equals(name)) {
-            maxKeepAliveRequests = Integer.parseInt((String) value.toString());
-        } else if ("port".equals(name)) {
-            setPort(Integer.parseInt((String) value.toString()));
-        }
-*/
     }
 
     public Object getAttribute( String key ) {
@@ -186,7 +139,7 @@ public class Http11Protocol implements ProtocolHandler, MBeanRegistration
             log.error(sm.getString("http11protocol.endpoint.initerror"), ex);
             throw ex;
         }
-        log.info(sm.getString("http11protocol.init", "" + ep.getPort()));
+        log.info(sm.getString("http11protocol.init", getName()));
 
     }
     
@@ -198,19 +151,20 @@ public class Http11Protocol implements ProtocolHandler, MBeanRegistration
             try {
                 // XXX We should be able to configure it separately
                 // XXX It should be possible to use a single TP
-                tpOname=new ObjectName(domain + ":" + "type=ThreadPool,name=http" + ep.getPort());
-                Registry.getRegistry().registerComponent(tp, tpOname, null );
-                tp.setName("http" + ep.getPort());
+                tpOname=new ObjectName
+                    (domain + ":" + "type=ThreadPool,name=" + getName());
+                Registry.getRegistry(null, null)
+                    .registerComponent(tp, tpOname, null );
+                tp.setName(getName());
                 tp.setDaemon(false);
                 tp.addThreadPoolListener(new MXPoolListener(this, tp));
             } catch (Exception e) {
                 log.error("Can't register threadpool" );
             }
-            rgOname=new ObjectName( domain + 
-                    ":type=GlobalRequestProcessor,name=http" +
-                    ep.getPort());
-            Registry.getRegistry().registerComponent( cHandler.global,
-                    rgOname, null );
+            rgOname=new ObjectName
+                (domain + ":type=GlobalRequestProcessor,name=" + getName());
+            Registry.getRegistry(null, null).registerComponent
+                ( cHandler.global, rgOname, null );
         }
 
         try {
@@ -219,16 +173,36 @@ public class Http11Protocol implements ProtocolHandler, MBeanRegistration
             log.error(sm.getString("http11protocol.endpoint.starterror"), ex);
             throw ex;
         }
-        log.info(sm.getString("http11protocol.start", "" + ep.getPort()));
+        log.info(sm.getString("http11protocol.start", getName()));
+    }
+
+    public void pause() throws Exception {
+        try {
+            ep.pauseEndpoint();
+        } catch (Exception ex) {
+            log.error(sm.getString("http11protocol.endpoint.pauseerror"), ex);
+            throw ex;
+        }
+        log.info(sm.getString("http11protocol.pause", getName()));
+    }
+
+    public void resume() throws Exception {
+        try {
+            ep.resumeEndpoint();
+        } catch (Exception ex) {
+            log.error(sm.getString("http11protocol.endpoint.resumeerror"), ex);
+            throw ex;
+        }
+        log.info(sm.getString("http11protocol.resume", getName()));
     }
 
     public void destroy() throws Exception {
-        log.info("Stoping http11 protocol on " + ep.getPort() + " " + tpOname);
+        log.info(sm.getString("http11protocol.stop", getName()));
         ep.stopEndpoint();
         if( tpOname!=null ) 
-            Registry.getRegistry().unregisterComponent(tpOname);
+            Registry.getRegistry(null, null).unregisterComponent(tpOname);
         if( rgOname != null ) 
-            Registry.getRegistry().unregisterComponent(rgOname);
+            Registry.getRegistry(null, null).unregisterComponent(rgOname);
     }
     
     // -------------------- Properties--------------------
@@ -246,6 +220,7 @@ public class Http11Protocol implements ProtocolHandler, MBeanRegistration
     private int maxKeepAliveRequests=100; // as in Apache HTTPD server
     private int timeout = 300000;   // 5 minutes as in Apache HTTPD server
     private int maxPostSize = 2 * 1024 * 1024;
+    private int maxHttpHeaderSize = 4 * 1024;
     private String reportedname;
     private int socketCloseDelay=-1;
     private boolean disableUploadTimeout = true;
@@ -300,6 +275,15 @@ public class Http11Protocol implements ProtocolHandler, MBeanRegistration
         setAttribute("minSpareThreads", "" + minSpareThreads);
     }
 
+    public void setThreadPriority(int threadPriority) {
+      ep.setThreadPriority(threadPriority);
+      setAttribute("threadPriority", "" + threadPriority);
+    }
+
+    public int getThreadPriority() {
+      return ep.getThreadPriority();
+    }
+
     // -------------------- Tcp setup --------------------
 
     public int getBacklog() {
@@ -330,6 +314,17 @@ public class Http11Protocol implements ProtocolHandler, MBeanRegistration
         setAttribute("address", "" + ia);
     }
     
+    public String getName() {
+        String encodedAddr = "";
+        if (getAddress() != null) {
+            encodedAddr = "" + getAddress();
+            if (encodedAddr.startsWith("/"))
+                encodedAddr = encodedAddr.substring(1);
+            encodedAddr = URLEncoder.encode(encodedAddr) + "-";
+        }
+        return ("http-" + encodedAddr + ep.getPort());
+    }
+    
     // commenting out for now since it's not doing anything
     //public void setHostName( String name ) {
     // ??? Doesn't seem to be used in existing or prev code
@@ -397,6 +392,15 @@ public class Http11Protocol implements ProtocolHandler, MBeanRegistration
         setAttribute("maxPostSize", "" + valueI);
     }
 
+    public int getMaxHttpHeaderSize() {
+        return maxHttpHeaderSize;
+    }
+    
+    public void setMaxHttpHeaderSize(int valueI) {
+        maxHttpHeaderSize = valueI;
+        setAttribute("maxHttpHeaderSize", "" + valueI);
+    }
+
     public String getRestrictedUserAgents() {
         return restrictedUserAgents;
     }
@@ -613,7 +617,7 @@ public class Http11Protocol implements ProtocolHandler, MBeanRegistration
             }
             ObjectName oname=(ObjectName)tpData[Http11Protocol.THREAD_DATA_OBJECT_NAME];
             if( oname==null ) return;
-            Registry.getRegistry().unregisterComponent(oname);
+            Registry.getRegistry(null, null).unregisterComponent(oname);
             Http11Processor processor = 
                 (Http11Processor) tpData[Http11Protocol.THREAD_DATA_PROCESSOR];
             RequestInfo rp=processor.getRequest().getRequestProcessor();
@@ -639,7 +643,8 @@ public class Http11Protocol implements ProtocolHandler, MBeanRegistration
         public Object[] init() {
             Object thData[]=new Object[3];
             
-            Http11Processor  processor = new Http11Processor();
+            Http11Processor  processor = 
+                new Http11Processor(proto.maxHttpHeaderSize);
             processor.setAdapter( proto.adapter );
             processor.setThreadPool( proto.tp );
             processor.setMaxKeepAliveRequests( proto.maxKeepAliveRequests );
@@ -659,10 +664,10 @@ public class Http11Protocol implements ProtocolHandler, MBeanRegistration
                 try {
                     RequestInfo rp=processor.getRequest().getRequestProcessor();
                     rp.setGlobalProcessor(global);
-                    ObjectName rpName=new ObjectName(proto.getDomain() + 
-                            ":type=RequestProcessor,worker=http" +
-                            proto.ep.getPort() +",name=HttpRequest" + count++ );
-                    Registry.getRegistry().registerComponent( rp, rpName, null);
+                    ObjectName rpName=new ObjectName
+                        (proto.getDomain() + ":type=RequestProcessor,worker=" 
+                         + proto.getName() +",name=HttpRequest" + count++ );
+                    Registry.getRegistry(null, null).registerComponent( rp, rpName, null);
                     thData[Http11Protocol.THREAD_DATA_OBJECT_NAME]=rpName;
                 } catch( Exception ex ) {
                     log.warn("Error registering request");
@@ -714,12 +719,12 @@ public class Http11Protocol implements ProtocolHandler, MBeanRegistration
                 TcpConnection.shutdownInput( socket );
             } catch(java.net.SocketException e) {
                 // SocketExceptions are normal
-                proto.log.debug
+                Http11Protocol.log.debug
                     (sm.getString
                      ("http11protocol.proto.socketexception.debug"), e);
             } catch (java.io.IOException e) {
                 // IOExceptions are normal 
-                proto.log.debug
+                Http11Protocol.log.debug
                     (sm.getString
                      ("http11protocol.proto.ioexception.debug"), e);
             }
@@ -730,7 +735,8 @@ public class Http11Protocol implements ProtocolHandler, MBeanRegistration
                 // any other exception or error is odd. Here we log it
                 // with "ERROR" level, so it will show up even on
                 // less-than-verbose logs.
-                proto.log.error(sm.getString("http11protocol.proto.error"), e);
+                Http11Protocol.log.error
+                    (sm.getString("http11protocol.proto.error"), e);
             } finally {
                 //       if(proto.adapter != null) proto.adapter.recycle();
                 //                processor.recycle();
@@ -756,31 +762,27 @@ public class Http11Protocol implements ProtocolHandler, MBeanRegistration
      *  @exception TomcatException Unable to resolve classes
      */
     private void checkSocketFactory() throws Exception {
-    if(secure) {
-        try {
-        // The SSL setup code has been moved into
-        // SSLImplementation since SocketFactory doesn't
-        // provide a wide enough interface
-        sslImplementation=SSLImplementation.getInstance
-            (sslImplementationName);
-                socketFactory = 
-                        sslImplementation.getServerSocketFactory();
-        ep.setServerSocketFactory(socketFactory);
-        } catch (ClassNotFoundException e){
-        throw e;
+        if (secure) {
+            try {
+                // The SSL setup code has been moved into
+                // SSLImplementation since SocketFactory doesn't
+                // provide a wide enough interface
+                sslImplementation =
+                    SSLImplementation.getInstance(sslImplementationName);
+                socketFactory = sslImplementation.getServerSocketFactory();
+                ep.setServerSocketFactory(socketFactory);
+            } catch (ClassNotFoundException e){
+                throw e;
+            }
+        } else if (socketFactoryName != null) {
+            try {
+                socketFactory = string2SocketFactory(socketFactoryName);
+                ep.setServerSocketFactory(socketFactory);
+            } catch(Exception sfex) {
+                throw sfex;
+            }
         }
     }
-    else {
-        if (socketFactoryName != null) {
-        try {
-            socketFactory = string2SocketFactory(socketFactoryName);
-            ep.setServerSocketFactory(socketFactory);
-        } catch(Exception sfex) {
-            throw sfex;
-        }
-        }
-    }
-    }
 
     /*
     public boolean isKeystoreSet() {
