@@ -1,60 +1,18 @@
-/* -*- Mode: C; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: nil-*- */
-/* ========================================================================= *
- *                                                                           *
- *                 The Apache Software License,  Version 1.1                 *
- *                                                                           *
- *          Copyright (c) 1999-2003 The Apache Software Foundation.          *
- *                           All rights reserved.                            *
- *                                                                           *
- * ========================================================================= *
- *                                                                           *
- * Redistribution and use in source and binary forms,  with or without modi- *
- * fication, are permitted provided that the following conditions are met:   *
- *                                                                           *
- * 1. Redistributions of source code  must retain the above copyright notice *
- *    notice, this list of conditions and the following disclaimer.          *
- *                                                                           *
- * 2. Redistributions  in binary  form  must  reproduce the  above copyright *
- *    notice,  this list of conditions  and the following  disclaimer in the *
- *    documentation and/or other materials provided with the distribution.   *
- *                                                                           *
- * 3. The end-user documentation  included with the redistribution,  if any, *
- *    must include the following acknowlegement:                             *
- *                                                                           *
- *       "This product includes  software developed  by the Apache  Software *
- *        Foundation <http://www.apache.org/>."                              *
- *                                                                           *
- *    Alternately, this acknowlegement may appear in the software itself, if *
- *    and wherever such third-party acknowlegements normally appear.         *
- *                                                                           *
- * 4. The names  "The  Jakarta  Project",  "Jk",  and  "Apache  Software     *
- *    Foundation"  must not be used  to endorse or promote  products derived *
- *    from this  software without  prior  written  permission.  For  written *
- *    permission, please contact <apache@apache.org>.                        *
- *                                                                           *
- * 5. Products derived from this software may not be called "Apache" nor may *
- *    "Apache" appear in their names without prior written permission of the *
- *    Apache Software Foundation.                                            *
- *                                                                           *
- * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED WARRANTIES *
- * INCLUDING, BUT NOT LIMITED TO,  THE IMPLIED WARRANTIES OF MERCHANTABILITY *
- * AND FITNESS FOR  A PARTICULAR PURPOSE  ARE DISCLAIMED.  IN NO EVENT SHALL *
- * THE APACHE  SOFTWARE  FOUNDATION OR  ITS CONTRIBUTORS  BE LIABLE  FOR ANY *
- * DIRECT,  INDIRECT,   INCIDENTAL,  SPECIAL,  EXEMPLARY,  OR  CONSEQUENTIAL *
- * DAMAGES (INCLUDING,  BUT NOT LIMITED TO,  PROCUREMENT OF SUBSTITUTE GOODS *
- * OR SERVICES;  LOSS OF USE,  DATA,  OR PROFITS;  OR BUSINESS INTERRUPTION) *
- * HOWEVER CAUSED AND  ON ANY  THEORY  OF  LIABILITY,  WHETHER IN  CONTRACT, *
- * STRICT LIABILITY, OR TORT  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN *
- * ANY  WAY  OUT OF  THE  USE OF  THIS  SOFTWARE,  EVEN  IF  ADVISED  OF THE *
- * POSSIBILITY OF SUCH DAMAGE.                                               *
- *                                                                           *
- * ========================================================================= *
- *                                                                           *
- * This software  consists of voluntary  contributions made  by many indivi- *
- * duals on behalf of the  Apache Software Foundation.  For more information *
- * on the Apache Software Foundation, please see <http://www.apache.org/>.   *
- *                                                                           *
- * ========================================================================= */
+/*
+ *  Copyright 1999-2004 The Apache Software Foundation
+ *
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
+ */
 
 /***************************************************************************
  * Description: Definitions of the objects used during the service step.   *
@@ -63,7 +21,7 @@
  * Author:      Gal Shachor <shachor@il.ibm.com>                           *
  * Author:      Dan Milstein <danmil@shore.net>                            *
  * Author:      Henri Gomez <hgomez@apache.org>                            *
- * Version:     $Revision: 1.15 $                                          *
+ * Version:     $Revision: 1.17 $                                          *
  ***************************************************************************/
 
 #ifndef JK_SERVICE_H
@@ -74,6 +32,7 @@
 #include "jk_logger.h"
 #include "jk_pool.h"
 #include "jk_uri_worker_map.h"
+#include "jk_msg_buff.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -242,6 +201,12 @@ struct jk_ws_service {
      * and JK_FALSE on failure.
      */
 
+    /*
+     * Area to get POST data for fail-over recovery in POST
+     */
+    jk_msg_buf_t    *reco_buf; 
+    int		    reco_status;
+
     /*
      * Send the response headers to the browser.
      */
