@@ -1,67 +1,19 @@
 /*
- * $Header: /home/cvs/jakarta-tomcat-connectors/util/java/org/apache/tomcat/util/net/PoolTcpEndpoint.java,v 1.31 2004/01/13 10:16:38 remm Exp $
- * $Revision: 1.31 $
- * $Date: 2004/01/13 10:16:38 $
+ *  Copyright 1999-2004 The Apache Software Foundation
  *
- * ====================================================================
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
  *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Tomcat", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
- *
- * [Additional notices, if required by prior licensing conditions]
+ *      http://www.apache.org/licenses/LICENSE-2.0
  *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
  */
 
-
 package org.apache.tomcat.util.net;
 
 import java.io.IOException;
@@ -75,7 +27,6 @@ import java.security.AccessControlException;
 
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
-import org.apache.tomcat.util.collections.SimplePool;
 import org.apache.tomcat.util.res.StringManager;
 import org.apache.tomcat.util.threads.ThreadPool;
 import org.apache.tomcat.util.threads.ThreadPoolRunnable;
@@ -101,6 +52,7 @@ import org.apache.tomcat.util.threads.ThreadPoolRunnable;
  * @author James Todd [gonzo@eng.sun.com]
  * @author Costin@eng.sun.com
  * @author Gal Shachor [shachor@il.ibm.com]
+ * @author Yoav Shapira <yoavs@apache.org>
  */
 public class PoolTcpEndpoint { // implements Endpoint {
 
@@ -127,13 +79,12 @@ public class PoolTcpEndpoint { // implements Endpoint {
 
     ThreadPoolRunnable listener;
     private volatile boolean running = false;
+    private volatile boolean paused = false;
     private boolean initialized = false;
     private boolean reinitializing = false;
     static final int debug=0;
 
     ThreadPool tp;
-    // XXX Do we need it for backward compat ?
-    //protected Log _log=Log.getLog("tc/PoolTcpEndpoint", "PoolTcpEndpoint");
 
     static Log log=LogFactory.getLog(PoolTcpEndpoint.class );
 
@@ -142,7 +93,6 @@ public class PoolTcpEndpoint { // implements Endpoint {
     protected int socketTimeout=-1;
     
     public PoolTcpEndpoint() {
-	//	super("tc_log");	// initialize default logger
 	tp = new ThreadPool();
     }
 
@@ -187,6 +137,14 @@ public class PoolTcpEndpoint { // implements Endpoint {
         return tp.getMinSpareThreads();
     }
 
+    public void setThreadPriority(int threadPriority) {
+      tp.setThreadPriority(threadPriority);
+    }
+
+    public int getThreadPriority() {
+      return tp.getThreadPriority();
+    }
+
     public int getPort() {
         return port;
     }
@@ -227,6 +185,10 @@ public class PoolTcpEndpoint { // implements Endpoint {
 	return running;
     }
     
+    public boolean isPaused() {
+	return paused;
+    }
+    
     /**
      * Allows the server developer to specify the backlog that
      * should be used for server sockets. By default, this value
@@ -322,6 +284,7 @@ public class PoolTcpEndpoint { // implements Endpoint {
 	    tp.start();
 	}
 	running = true;
+        paused = false;
         if(isPool) {
     	    listener = new TcpWorkerThread(this);
             tp.runIt(listener);
@@ -330,6 +293,19 @@ public class PoolTcpEndpoint { // implements Endpoint {
 	}
     }
 
+    public void pauseEndpoint() {
+        if (running && !paused) {
+            paused = true;
+            unlockAccept();
+        }
+    }
+
+    public void resumeEndpoint() {
+        if (running) {
+            paused = false;
+        }
+    }
+
     public void stopEndpoint() {
 	if (running) {
 	    tp.shutdown();
@@ -341,6 +317,18 @@ public class PoolTcpEndpoint { // implements Endpoint {
     }
 
     protected void closeServerSocket() {
+        if (!paused)
+            unlockAccept();
+        try {
+            if( serverSocket!=null)
+                serverSocket.close();
+        } catch(Exception e) {
+            log.error("Caught exception trying to close socket.", e);
+        }
+        serverSocket = null;
+    }
+
+    protected void unlockAccept() {
         Socket s = null;
         try {
             // Need to create a connection to unlock the accept();
@@ -353,8 +341,8 @@ public class PoolTcpEndpoint { // implements Endpoint {
                 s.setSoLinger(true, 0);
             }
         } catch(Exception e) {
-            log.error("Caught exception trying to unlock accept on " + port
-                    + " " + e.toString());
+            log.debug("Caught exception trying to unlock accept on " + port
+                      + " " + e.toString());
         } finally {
             if (s != null) {
                 try {
@@ -364,13 +352,6 @@ public class PoolTcpEndpoint { // implements Endpoint {
                 }
             }
         }
-        try {
-            if( serverSocket!=null)
-                serverSocket.close();
-        } catch(Exception e) {
-            log.error("Caught exception trying to close socket.", e);
-        }
-        serverSocket = null;
     }
 
     // -------------------- Private methods
@@ -537,7 +518,7 @@ class TcpWorkerThread implements ThreadPoolRunnable {
     PoolTcpEndpoint endpoint;
     
     public TcpWorkerThread(PoolTcpEndpoint endpoint) {
-	this.endpoint = endpoint;
+        this.endpoint = endpoint;
     }
 
     public Object[] getInitData() {
@@ -550,65 +531,83 @@ class TcpWorkerThread implements ThreadPoolRunnable {
     
     public void runIt(Object perThrData[]) {
 
-	// Create per-thread cache
-	if (endpoint.isRunning()) {
-	    Socket s = null;
-	    try {
+        // Create per-thread cache
+        if (endpoint.isRunning()) {
+
+            // Loop if endpoint is paused
+            while (endpoint.isPaused()) {
+                try {
+                    Thread.sleep(1000);
+                } catch (InterruptedException e) {
+                    // Ignore
+                }
+            }
+
+            // Accept a new connection
+            Socket s = null;
+            try {
                 s = endpoint.acceptSocket();
-	    } finally {
-		// Continue accepting on another thread...
+            } finally {
+                // Continue accepting on another thread...
                 if (endpoint.isRunning()) {
                     endpoint.tp.runIt(this);
                 }
             }
-	    if (null != s) {
 
+            // Process the connection
+            if (null != s) {
                 TcpConnection con = null;
                 int step = 1;
                 try {
 
                     // 1: Set socket options: timeout, linger, etc
-                    endpoint.setSocketOptions( s );
+                    endpoint.setSocketOptions(s);
 
                     // 2: SSL handshake
                     step = 2;
- 		    if(endpoint.getServerSocketFactory()!=null) {
+                    if (endpoint.getServerSocketFactory() != null) {
                         endpoint.getServerSocketFactory().handshake(s);
- 		    }
+                    }
 
                     // 3: Process the connection
                     step = 3;
                     con = (TcpConnection) perThrData[0];
-		    con.setEndpoint(endpoint);
-		    con.setSocket(s);
-		    endpoint.getConnectionHandler()
-                        .processConnection(con, (Object []) perThrData[1]);
+                    con.setEndpoint(endpoint);
+                    con.setSocket(s);
+                    endpoint.getConnectionHandler().processConnection(
+                        con,
+                        (Object[]) perThrData[1]);
 
                 } catch (SocketException se) {
-                    endpoint.log.error
-                        ("Remote Host " + s.getInetAddress() +
-                         " SocketException: " + se.getMessage());
+                    PoolTcpEndpoint.log.error(
+                        "Remote Host "
+                            + s.getInetAddress()
+                            + " SocketException: "
+                            + se.getMessage());
                     // Try to close the socket
                     try {
                         s.close();
-                    } catch (IOException e) {}
+                    } catch (IOException e) {
+                    }
                 } catch (Throwable t) {
                     if (step == 2) {
-                        endpoint.log.debug("Handshake failed", t);
+                        PoolTcpEndpoint.log.debug("Handshake failed", t);
                     } else {
-                        endpoint.log.error("Unexpected error", t);
+                        PoolTcpEndpoint.log.error("Unexpected error", t);
                     }
                     // Try to close the socket
                     try {
                         s.close();
-                    } catch (IOException e) {}
+                    } catch (IOException e) {
+                    }
                 } finally {
                     if (con != null) {
                         con.recycle();
                     }
                 }
-	    }
-	}
-    }
+            }
 
+        }
+    }
+    
 }
