@@ -1,61 +1,17 @@
 /*
+ *  Copyright 1999-2004 The Apache Software Foundation
  *
- * ====================================================================
+ *  Licensed under the Apache License, Version 2.0 (the "License");
+ *  you may not use this file except in compliance with the License.
+ *  You may obtain a copy of the License at
  *
- * The Apache Software License, Version 1.1
- *
- * Copyright (c) 1999 The Apache Software Foundation.  All rights
- * reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions
- * are met:
- *
- * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright
- *    notice, this list of conditions and the following disclaimer in
- *    the documentation and/or other materials provided with the
- *    distribution.
- *
- * 3. The end-user documentation included with the redistribution, if
- *    any, must include the following acknowlegement:
- *       "This product includes software developed by the
- *        Apache Software Foundation (http://www.apache.org/)."
- *    Alternately, this acknowlegement may appear in the software itself,
- *    if and wherever such third-party acknowlegements normally appear.
- *
- * 4. The names "The Jakarta Project", "Tomcat", and "Apache Software
- *    Foundation" must not be used to endorse or promote products derived
- *    from this software without prior written permission. For written
- *    permission, please contact apache@apache.org.
- *
- * 5. Products derived from this software may not be called "Apache"
- *    nor may "Apache" appear in their names without prior written
- *    permission of the Apache Group.
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
- * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
- * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
- * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
- * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
- * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
- * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
- * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
- * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
- * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
- * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
- * SUCH DAMAGE.
- * ====================================================================
- *
- * This software consists of voluntary contributions made by many
- * individuals on behalf of the Apache Software Foundation.  For more
- * information on the Apache Software Foundation, please see
- * <http://www.apache.org/>.
- *
- * [Additional notices, if required by prior licensing conditions]
+ *      http://www.apache.org/licenses/LICENSE-2.0
  *
+ *  Unless required by applicable law or agreed to in writing, software
+ *  distributed under the License is distributed on an "AS IS" BASIS,
+ *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ *  See the License for the specific language governing permissions and
+ *  limitations under the License.
  */
 
 package org.apache.tomcat.util.threads;
@@ -68,7 +24,10 @@ import org.apache.tomcat.util.res.StringManager;
 /**
  * A thread pool that is trying to copy the apache process management.
  *
+ * Should we remove this in favor of Doug Lea's thread package?
+ *
  * @author Gal Shachor
+ * @author Yoav Shapira <yoavs@apache.org>
  */
 public class ThreadPool  {
 
@@ -148,6 +107,11 @@ public class ThreadPool  {
      */
     protected int sequence = 1;
 
+    /**
+     * Thread priority.
+     */
+    protected int threadPriority = Thread.NORM_PRIORITY;
+
 
     /**
      * Constructor.
@@ -164,22 +128,11 @@ public class ThreadPool  {
 
     /** Create a ThreadPool instance.
      *
-     * @param jmx True if you want a pool with JMX support. A regular pool
-     *  will be returned if JMX or the modeler are not available.
-     *
+     * @param jmx UNUSED 
      * @return ThreadPool instance. If JMX support is requested, you need to
      *   call register() in order to set a name.
      */
     public static ThreadPool createThreadPool(boolean jmx) {
-//        if( jmx ) {
-//            try {
-//                Class.forName( "org.apache.commons.modeler.Registry");
-//                Class tpc=Class.forName( "org.apache.tomcat.util.threads.ThreadPoolMX");
-//                ThreadPool res=(ThreadPool)tpc.newInstance();
-//                return res;
-//            } catch( Exception ex ) {
-//            }
-//        }
         return new ThreadPool();
     }
 
@@ -193,12 +146,56 @@ public class ThreadPool  {
         pool = new ControlRunnable[maxThreads];
 
         openThreads(minSpareThreads);
-        monitor = new MonitorRunnable(this);
+        if (maxSpareThreads < maxThreads) {
+            monitor = new MonitorRunnable(this);
+        }
     }
 
     public MonitorRunnable getMonitor() {
         return monitor;
     }
+  
+    /**
+     * Sets the thread priority for current
+     * and future threads in this pool.
+     *
+     * @param threadPriority The new priority
+     * @throws IllegalArgumentException If the specified
+     *  priority is less than Thread.MIN_PRIORITY or
+     *  more than Thread.MAX_PRIORITY 
+     */
+    public synchronized void setThreadPriority(int threadPriority) {
+        if(log.isDebugEnabled())
+            log.debug(getClass().getName() +
+                      ": setPriority(" + threadPriority + "): here.");
+
+      if (threadPriority < Thread.MIN_PRIORITY) {
+        throw new IllegalArgumentException("new priority < MIN_PRIORITY");
+      } else if (threadPriority > Thread.MAX_PRIORITY) {
+        throw new IllegalArgumentException("new priority > MIN_PRIORITY");
+      }
+
+      // Set for future threads
+      this.threadPriority = threadPriority;
+
+      Enumeration currentThreads = getThreads();
+      Thread t = null;
+      while(currentThreads.hasMoreElements()) {
+        t = (Thread) currentThreads.nextElement();
+        t.setPriority(threadPriority);
+      } 
+    }
+
+    /**
+     * Returns the priority level of current and
+     * future threads in this pool.
+     *
+     * @return The priority
+     */
+    public int getThreadPriority() {
+      return threadPriority;
+    }   
+     
 
     public void setMaxThreads(int maxThreads) {
         this.maxThreads = maxThreads;
@@ -387,9 +384,11 @@ public class ThreadPool  {
     public synchronized void shutdown() {
         if(!stopThePool) {
             stopThePool = true;
-            monitor.terminate();
-            monitor = null;
-            for(int i = 0 ; i < (currentThreadCount - currentThreadsBusy - 1) ; i++) {
+            if (monitor != null) {
+                monitor.terminate();
+                monitor = null;
+            }
+            for(int i = 0; i < currentThreadCount - currentThreadsBusy; i++) {
                 try {
                     pool[i].terminate();
                 } catch(Throwable t) {
@@ -645,89 +644,89 @@ public class ThreadPool  {
 
         public void run() {
             boolean _shouldRun = false;
-            boolean _shouldTerminate = false; 
+            boolean _shouldTerminate = false;
             ThreadPoolRunnable _toRun = null;
-          try {
-            while(true) {
-                try {
-                    /* Wait for work. */
-                    synchronized(this) {
-                        while (!shouldRun && !shouldTerminate) {
-                            this.wait();
-                        }
-                        _shouldRun = shouldRun;
-                        _shouldTerminate = shouldTerminate;
-                        _toRun = toRun;
-                    }
-
-                    if( _shouldTerminate ) {
-                            if( p.log.isDebugEnabled())
-                                p.log.debug( "Terminate");
-                            break;
-                    }
-
-                    /* Check if should execute a runnable.  */
+            try {
+                while (true) {
                     try {
-                        if(noThData) {
-                            if( _toRun != null ) {
-                                Object thData[]=_toRun.getInitData();
-                                t.setThreadData(p, thData);
-                                if(p.log.isDebugEnabled())
-                                    p.log.debug( "Getting new thread data");
+                        /* Wait for work. */
+                        synchronized (this) {
+                            while (!shouldRun && !shouldTerminate) {
+                                this.wait();
                             }
-                            noThData = false;
+                            _shouldRun = shouldRun;
+                            _shouldTerminate = shouldTerminate;
+                            _toRun = toRun;
                         }
 
-                        if(_shouldRun) {
-			    if( _toRun != null ) { 
-                                _toRun.runIt(t.getThreadData(p));
-                            } else if( toRunRunnable != null ) { 
-                                toRunRunnable.run();
-                            } else {
-                                if( p.log.isDebugEnabled())
-                                    p.log.debug( "No toRun ???");
-                            }
+                        if (_shouldTerminate) {
+                            if (ThreadPool.log.isDebugEnabled())
+                                ThreadPool.log.debug("Terminate");
+                            break;
                         }
-                    } catch(Throwable t) {
-			p.log.error(sm.getString("threadpool.thread_error",
-                                                 t, toRun.toString()));
-                       /*
-                        * The runnable throw an exception (can be even a ThreadDeath),
-                        * signalling that the thread die.
-                        *
-			* The meaning is that we should release the thread from
-			* the pool.
-			*/
-                        shouldTerminate = true;
-                        shouldRun = false;
-                        p.notifyThreadEnd(this);
-                    } finally {
-                        if(_shouldRun) {
-                            shouldRun = false;
+
+                        /* Check if should execute a runnable.  */
+                        try {
+                            if (noThData) {
+                                if (_toRun != null) {
+                                    Object thData[] = _toRun.getInitData();
+                                    t.setThreadData(p, thData);
+                                    if (ThreadPool.log.isDebugEnabled())
+                                        ThreadPool.log.debug(
+                                            "Getting new thread data");
+                                }
+                                noThData = false;
+                            }
+
+                            if (_shouldRun) {
+                                if (_toRun != null) {
+                                    _toRun.runIt(t.getThreadData(p));
+                                } else if (toRunRunnable != null) {
+                                    toRunRunnable.run();
+                                } else {
+                                    if (ThreadPool.log.isDebugEnabled())
+                                    ThreadPool.log.debug("No toRun ???");
+                                }
+                            }
+                        } catch (Throwable t) {
+                            ThreadPool.log.error(sm.getString
+                                ("threadpool.thread_error", t, toRun.toString()));
                             /*
-			     * Notify the pool that the thread is now idle.
-                             */
-                            p.returnController(this);
+                             * The runnable throw an exception (can be even a ThreadDeath),
+                             * signalling that the thread die.
+                             *
+                            * The meaning is that we should release the thread from
+                            * the pool.
+                            */
+                            shouldTerminate = true;
+                            shouldRun = false;
+                            p.notifyThreadEnd(this);
+                        } finally {
+                            if (_shouldRun) {
+                                shouldRun = false;
+                                /*
+                                * Notify the pool that the thread is now idle.
+                                 */
+                                p.returnController(this);
+                            }
                         }
-                    }
 
-                    /*
-		     * Check if should terminate.
-		     * termination happens when the pool is shutting down.
-		     */
-                    if(_shouldTerminate) {
-                        break;
+                        /*
+                        * Check if should terminate.
+                        * termination happens when the pool is shutting down.
+                        */
+                        if (_shouldTerminate) {
+                            break;
+                        }
+                    } catch (InterruptedException ie) { /* for the wait operation */
+                        // can never happen, since we don't call interrupt
+                        ThreadPool.log.error("Unexpected exception", ie);
                     }
-                } catch(InterruptedException ie) { /* for the wait operation */
-		    // can never happen, since we don't call interrupt
-    		    p.log.error("Unexpected exception", ie);
                 }
+            } finally {
+                p.removeThread(Thread.currentThread());
             }
-          } finally {
-              p.removeThread(Thread.currentThread());
-          }
         }
-
         /** Run a task
          *
          * @param toRun
